"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AudioAttachment = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const photo_size_1 = require("../structures/photo-size");
const file_attachment_1 = require("./file-attachment");
const helpers_1 = require("../../utils/helpers");
/**
 * This object represents an audio file to be treated as music by the Telegram
 * clients.
 */
// TODO: extended: ['fileId', 'fileUniqueId']
let AudioAttachment = class AudioAttachment extends file_attachment_1.FileAttachment {
    constructor() {
        super(...arguments);
        this.attachmentType = 'audio';
    }
    /** Duration of the audio in seconds as defined by sender */
    get duration() {
        return this.payload.duration;
    }
    /** Performer of the audio as defined by sender or by audio tags */
    get performer() {
        return this.payload.performer;
    }
    /** Title of the audio as defined by sender or by audio tags */
    get title() {
        return this.payload.title;
    }
    /** Original filename as defined by sender */
    get fileName() {
        return this.payload.file_name;
    }
    /** MIME type of the file as defined by sender */
    get mimeType() {
        return this.payload.mime_type;
    }
    /** File size */
    get fileSize() {
        return this.payload.file_size;
    }
    /** Thumbnail of the album cover to which the music file belongs */
    get thumbnail() {
        const { thumbnail } = this.payload;
        if (!thumbnail) {
            return;
        }
        return new photo_size_1.PhotoSize(thumbnail);
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], AudioAttachment.prototype, "duration", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], AudioAttachment.prototype, "performer", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], AudioAttachment.prototype, "title", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], AudioAttachment.prototype, "fileName", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], AudioAttachment.prototype, "mimeType", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], AudioAttachment.prototype, "fileSize", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], AudioAttachment.prototype, "thumbnail", null);
AudioAttachment = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], AudioAttachment);
exports.AudioAttachment = AudioAttachment;
(0, helpers_1.memoizeGetters)(AudioAttachment, ['thumbnail']);
