"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocumentAttachment = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const photo_size_1 = require("../structures/photo-size");
const file_attachment_1 = require("./file-attachment");
const helpers_1 = require("../../utils/helpers");
/**
 * This object represents a general file (as opposed to photos, voice messages
 * and audio files).
 */
// TODO: extended: ['fileId', 'fileUniqueId']
let DocumentAttachment = class DocumentAttachment extends file_attachment_1.FileAttachment {
    constructor() {
        super(...arguments);
        this.attachmentType = 'document';
    }
    /** Document thumbnail as defined by sender */
    get thumbnail() {
        const { thumbnail } = this.payload;
        if (!thumbnail) {
            return;
        }
        return new photo_size_1.PhotoSize(thumbnail);
    }
    /** Original filename as defined by sender */
    get fileName() {
        return this.payload.file_name;
    }
    /** MIME type of the file as defined by sender */
    get mimeType() {
        return this.payload.mime_type;
    }
    /** File size */
    get fileSize() {
        return this.payload.file_size;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], DocumentAttachment.prototype, "thumbnail", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], DocumentAttachment.prototype, "fileName", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], DocumentAttachment.prototype, "mimeType", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], DocumentAttachment.prototype, "fileSize", null);
DocumentAttachment = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], DocumentAttachment);
exports.DocumentAttachment = DocumentAttachment;
(0, helpers_1.memoizeGetters)(DocumentAttachment, ['thumbnail']);
