"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VideoNoteAttachment = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const photo_size_1 = require("../structures/photo-size");
const file_attachment_1 = require("./file-attachment");
const helpers_1 = require("../../utils/helpers");
/** This object represents a video message. */
// TODO: extended: ['fileId', 'fileUniqueId']
let VideoNoteAttachment = class VideoNoteAttachment extends file_attachment_1.FileAttachment {
    constructor() {
        super(...arguments);
        this.attachmentType = 'video_note';
    }
    /**
     * Video width and height (diameter of the video message) as defined by
     * sender
     */
    get length() {
        return this.payload.length;
    }
    /** Duration of the video in seconds as defined by sender */
    get duration() {
        return this.payload.duration;
    }
    /** Video thumbnail */
    get thumbnail() {
        const { thumbnail } = this.payload;
        if (!thumbnail) {
            return;
        }
        return new photo_size_1.PhotoSize(thumbnail);
    }
    /** File size */
    get fileSize() {
        return this.payload.file_size;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], VideoNoteAttachment.prototype, "length", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], VideoNoteAttachment.prototype, "duration", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], VideoNoteAttachment.prototype, "thumbnail", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], VideoNoteAttachment.prototype, "fileSize", null);
VideoNoteAttachment = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], VideoNoteAttachment);
exports.VideoNoteAttachment = VideoNoteAttachment;
(0, helpers_1.memoizeGetters)(VideoNoteAttachment, ['thumbnail']);
