"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VideoAttachment = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const photo_size_1 = require("../structures/photo-size");
const file_attachment_1 = require("./file-attachment");
const helpers_1 = require("../../utils/helpers");
/** This object represents a video file. */
// TODO: extended: ['fileId', 'fileUniqueId']
let VideoAttachment = class VideoAttachment extends file_attachment_1.FileAttachment {
    constructor() {
        super(...arguments);
        this.attachmentType = 'video';
    }
    /** Video width as defined by sender */
    get width() {
        return this.payload.width;
    }
    /** Video height as defined by sender */
    get height() {
        return this.payload.height;
    }
    /** Duration of the video in seconds as defined by sender */
    get duration() {
        return this.payload.duration;
    }
    /** Video thumbnail */
    get thumbnail() {
        const { thumbnail } = this.payload;
        if (!thumbnail) {
            return;
        }
        return new photo_size_1.PhotoSize(thumbnail);
    }
    /** Original filename as defined by sender */
    get fileName() {
        return this.payload.file_name;
    }
    /** Mime type of a file as defined by sender */
    get mimeType() {
        return this.payload.mime_type;
    }
    /** File size */
    get fileSize() {
        return this.payload.file_size;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], VideoAttachment.prototype, "width", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], VideoAttachment.prototype, "height", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], VideoAttachment.prototype, "duration", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], VideoAttachment.prototype, "thumbnail", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], VideoAttachment.prototype, "fileName", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], VideoAttachment.prototype, "mimeType", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], VideoAttachment.prototype, "fileSize", null);
VideoAttachment = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], VideoAttachment);
exports.VideoAttachment = VideoAttachment;
(0, helpers_1.memoizeGetters)(VideoAttachment, ['thumbnail']);
