"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputMessageContent = void 0;
/**
 * This object represents the content of a message to be sent as a result of an inline query
 *
 * @example
 * context.answerInlineQuery([
 *   InlineQueryResult.article({
 *     id,
 *     title: 'definitely an article!',
 *     input_message_content: InputMessageContent.text('definitely a message!')
 *   })
 * ])
 */
class InputMessageContent {
    /** Creates a `TelegramInputTextMessageContent` object */
    static text(text, params = {}) {
        return {
            message_text: text,
            ...params
        };
    }
    /** Creates a `TelegramInputLocationMessageContent` object */
    static location(latitude, longitude, params = {}) {
        return {
            latitude,
            longitude,
            ...params
        };
    }
    /** Creates a `TelegramInputVenueMessageContent` object */
    static venue(params) {
        return {
            ...params
        };
    }
    /** Creates a `TelegramInputContactMessageContent` object */
    static contact(params) {
        return {
            ...params
        };
    }
    /** Creates a `TelegramInputInvoiceMessageContent` object */
    static invoice(params) {
        return {
            ...params
        };
    }
}
exports.InputMessageContent = InputMessageContent;
