import * as Interfaces from '../../generated';
import type { OneOf, Optional } from '../../types/types';
/**
 * This class provides static methods for easier creation of `InlineQueryResultCached*` objects,
 * just like the `InlineQueryResult` class does for `InlineQueryResult*` objects
 *
 * @example
 * context.answerInlineQuery([
 *   InlineQueryResult.cached.audio({
 *     id,
 *     audio_file_id: fileId,
 *     caption: 'definitely a cached audio!'
 *   })
 * ])
 */
export declare class InlineQueryResultCached {
    /** Creates an `InlineQueryResultCachedAudio` object */
    static audio(params: Optional<Interfaces.TelegramInlineQueryResultCachedAudio, 'type'>): Interfaces.TelegramInlineQueryResultCachedAudio;
    /** Creates an `InlineQueryResultCachedDocument` object */
    static document(params: Optional<Interfaces.TelegramInlineQueryResultCachedDocument, 'type'>): Interfaces.TelegramInlineQueryResultCachedDocument;
    /** Creates an `InlineQueryResultCachedGif` object */
    static gif(params: Optional<Interfaces.TelegramInlineQueryResultCachedGif, 'type'>): Interfaces.TelegramInlineQueryResultCachedGif;
    /** Creates an `InlineQueryResultCachedMpeg4Gif` object */
    static mpeg4Gif(params: Optional<Interfaces.TelegramInlineQueryResultCachedMpeg4Gif, 'type'>): Interfaces.TelegramInlineQueryResultCachedMpeg4Gif;
    /** Creates an `InlineQueryResultCachedPhoto` object */
    static photo(params: Optional<Interfaces.TelegramInlineQueryResultCachedPhoto, 'type'>): Interfaces.TelegramInlineQueryResultCachedPhoto;
    /** Creates an `InlineQueryResultCachedSticker` object */
    static sticker(params: Optional<Interfaces.TelegramInlineQueryResultCachedSticker, 'type'>): Interfaces.TelegramInlineQueryResultCachedSticker;
    /** Creates an `InlineQueryResultCachedVideo` object */
    static video(params: Optional<Interfaces.TelegramInlineQueryResultCachedVideo, 'type'>): Interfaces.TelegramInlineQueryResultCachedVideo;
    /** Creates an `InlineQueryResultCachedAudio` object */
    static voice(params: Optional<Interfaces.TelegramInlineQueryResultCachedVoice, 'type'>): Interfaces.TelegramInlineQueryResultCachedVoice;
}
/**
 * This class provides static methods for easier creation of `InlineQueryResult*` objects
 *
 * @example
 * context.answerInlineQuery([
 *   InlineQueryResult.article({
 *     id,
 *     title: 'definitely an article!',
 *     input_message_content: InputMessageContent.text('definitely a message!')
 *   })
 * ])
 */
export declare class InlineQueryResult {
    static cached: typeof InlineQueryResultCached;
    /** Creates an `InlineQueryResultsButton` button that will be shown above inline query results */
    static button(text: string, params: OneOf<Optional<Interfaces.TelegramInlineQueryResultsButton, 'text'>, 'web_app' | 'start_parameter'>): Interfaces.TelegramInlineQueryResultsButton;
    /** Creates an `InlineQueryResultArticle` object */
    static article(params: Optional<Interfaces.TelegramInlineQueryResultArticle, 'type'>): Interfaces.TelegramInlineQueryResultArticle;
    /** Creates an `InlineQueryResultAudio` object */
    static audio(params: Optional<Interfaces.TelegramInlineQueryResultAudio, 'type'>): Interfaces.TelegramInlineQueryResultAudio;
    /** Creates an `InlineQueryResultContact` object */
    static contact(params: Optional<Interfaces.TelegramInlineQueryResultContact, 'type'>): Interfaces.TelegramInlineQueryResultContact;
    /** Creates an `InlineQueryResultGame` object */
    static game(params: Optional<Interfaces.TelegramInlineQueryResultGame, 'type'>): Interfaces.TelegramInlineQueryResultGame;
    /** Creates an `InlineQueryResultDocument` object */
    static document(params: Optional<Interfaces.TelegramInlineQueryResultDocument, 'type'>): Interfaces.TelegramInlineQueryResultDocument;
    /** Creates an `InlineQueryResultGif` object */
    static gif(params: Optional<Interfaces.TelegramInlineQueryResultGif, 'type'>): Interfaces.TelegramInlineQueryResultGif;
    /** Creates an `InlineQueryResultLocation` object */
    static location(params: Optional<Interfaces.TelegramInlineQueryResultLocation, 'type'>): Interfaces.TelegramInlineQueryResultLocation;
    /** Creates an `InlineQueryResultMpeg4Gif` object */
    static mpeg4Gif(params: Optional<Interfaces.TelegramInlineQueryResultMpeg4Gif, 'type'>): Interfaces.TelegramInlineQueryResultMpeg4Gif;
    /** Creates an `InlineQueryResultPhoto` object */
    static photo(params: Optional<Interfaces.TelegramInlineQueryResultPhoto, 'type'>): Interfaces.TelegramInlineQueryResultPhoto;
    /** Creates an `InlineQueryResultVenue` object */
    static venue(params: Optional<Interfaces.TelegramInlineQueryResultVenue, 'type'>): Interfaces.TelegramInlineQueryResultVenue;
    /** Creates an `InlineQueryResultVideo` object */
    static video(params: Optional<Interfaces.TelegramInlineQueryResultVideo, 'type'>): Interfaces.TelegramInlineQueryResultVideo;
    /** Creates an `InlineQueryResultVoice` object */
    static voice(params: Optional<Interfaces.TelegramInlineQueryResultVoice, 'type'>): Interfaces.TelegramInlineQueryResultVoice;
}
