"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InlineQueryResult = exports.InlineQueryResultCached = void 0;
/**
 * This class provides static methods for easier creation of `InlineQueryResultCached*` objects,
 * just like the `InlineQueryResult` class does for `InlineQueryResult*` objects
 *
 * @example
 * context.answerInlineQuery([
 *   InlineQueryResult.cached.audio({
 *     id,
 *     audio_file_id: fileId,
 *     caption: 'definitely a cached audio!'
 *   })
 * ])
 */
class InlineQueryResultCached {
    /** Creates an `InlineQueryResultCachedAudio` object */
    static audio(params) {
        return {
            type: 'audio',
            ...params
        };
    }
    /** Creates an `InlineQueryResultCachedDocument` object */
    static document(params) {
        return {
            type: 'document',
            ...params
        };
    }
    /** Creates an `InlineQueryResultCachedGif` object */
    static gif(params) {
        return {
            type: 'gif',
            ...params
        };
    }
    /** Creates an `InlineQueryResultCachedMpeg4Gif` object */
    static mpeg4Gif(params) {
        return {
            type: 'mpeg4_gif',
            ...params
        };
    }
    /** Creates an `InlineQueryResultCachedPhoto` object */
    static photo(params) {
        return {
            type: 'photo',
            ...params
        };
    }
    /** Creates an `InlineQueryResultCachedSticker` object */
    static sticker(params) {
        return {
            type: 'sticker',
            ...params
        };
    }
    /** Creates an `InlineQueryResultCachedVideo` object */
    static video(params) {
        return {
            type: 'video',
            ...params
        };
    }
    /** Creates an `InlineQueryResultCachedAudio` object */
    static voice(params) {
        return {
            type: 'voice',
            ...params
        };
    }
}
exports.InlineQueryResultCached = InlineQueryResultCached;
/**
 * This class provides static methods for easier creation of `InlineQueryResult*` objects
 *
 * @example
 * context.answerInlineQuery([
 *   InlineQueryResult.article({
 *     id,
 *     title: 'definitely an article!',
 *     input_message_content: InputMessageContent.text('definitely a message!')
 *   })
 * ])
 */
class InlineQueryResult {
    /** Creates an `InlineQueryResultsButton` button that will be shown above inline query results */
    static button(text, params) {
        return {
            text,
            ...params
        };
    }
    /** Creates an `InlineQueryResultArticle` object */
    static article(params) {
        return {
            type: 'article',
            ...params
        };
    }
    /** Creates an `InlineQueryResultAudio` object */
    static audio(params) {
        return {
            type: 'audio',
            ...params
        };
    }
    /** Creates an `InlineQueryResultContact` object */
    static contact(params) {
        return {
            type: 'contact',
            ...params
        };
    }
    /** Creates an `InlineQueryResultGame` object */
    static game(params) {
        return {
            type: 'game',
            ...params
        };
    }
    /** Creates an `InlineQueryResultDocument` object */
    static document(params) {
        return {
            type: 'document',
            ...params
        };
    }
    /** Creates an `InlineQueryResultGif` object */
    static gif(params) {
        return {
            type: 'gif',
            ...params
        };
    }
    /** Creates an `InlineQueryResultLocation` object */
    static location(params) {
        return {
            type: 'location',
            ...params
        };
    }
    /** Creates an `InlineQueryResultMpeg4Gif` object */
    static mpeg4Gif(params) {
        return {
            type: 'mpeg4_gif',
            ...params
        };
    }
    /** Creates an `InlineQueryResultPhoto` object */
    static photo(params) {
        return {
            type: 'photo',
            ...params
        };
    }
    /** Creates an `InlineQueryResultVenue` object */
    static venue(params) {
        return {
            type: 'venue',
            ...params
        };
    }
    /** Creates an `InlineQueryResultVideo` object */
    static video(params) {
        return {
            type: 'video',
            ...params
        };
    }
    /** Creates an `InlineQueryResultVoice` object */
    static voice(params) {
        return {
            type: 'voice',
            ...params
        };
    }
}
exports.InlineQueryResult = InlineQueryResult;
InlineQueryResult.cached = InlineQueryResultCached;
