"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputMedia = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
/**
 * This class provides static methods for easier `InputMedia` uploads
 *
 * @example
 * ```js
 * context.sendMediaGroup([
 *   InputMedia.photo(MediaSource.path(PATH_TO_FIRST_PHOTO)),
 *   InputMedia.photo(MediaSource.path(PATH_TO_SECOND_PHOTO), { caption: 'caption to second photo!' })
 * ])
 * ```
 *
 * It is also allowed to pass this as an argument to `sendMedia`:
 *
 * @example
 * ```js
 * context.sendMedia(
 *   InputMedia.document(MediaSource.path(PATH_TO_DOCUMENT), { caption: 'O_o' })
 * )
 * ```
 */
let InputMedia = class InputMedia {
    static animation(media, params) {
        return {
            type: 'animation',
            media,
            ...params
        };
    }
    static audio(media, params) {
        return {
            type: 'audio',
            media,
            ...params
        };
    }
    static document(media, params) {
        return {
            type: 'document',
            media,
            ...params
        };
    }
    static photo(media, params) {
        return {
            type: 'photo',
            media,
            ...params
        };
    }
    static video(media, params) {
        return {
            type: 'video',
            media,
            ...params
        };
    }
    static sticker(media, params) {
        return {
            type: 'sticker',
            media,
            ...params
        };
    }
    static videoNote(media, params) {
        return {
            type: 'video_note',
            media,
            ...params
        };
    }
    static voice(media, params) {
        return {
            type: 'voice',
            media,
            ...params
        };
    }
};
InputMedia = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], InputMedia);
exports.InputMedia = InputMedia;
