import * as Interfaces from '../../generated/telegram-interfaces';
interface TextButtonParams {
    text: string;
    payload: Record<string, any> | string;
}
interface UrlButtonParams {
    text: string;
    url: string;
}
interface WebAppButtonParams {
    text: string;
    url: string;
}
interface SwitchToCurrentChatButtonParams {
    text: string;
    query: string;
}
interface SwitchToChatButtonParams {
    text: string;
    query: string;
}
interface SwitchToChosenChatButtonParams {
    text: string;
    query?: string;
    allowUserChats?: boolean;
    allowBotChats?: boolean;
    allowGroupChats?: boolean;
    allowChannelChats?: boolean;
}
interface GameButtonParams {
    text: string;
    game: Interfaces.TelegramCallbackGame;
}
interface PayButtonParams {
    text: string;
}
interface LoginButtonParams {
    text: string;
    loginUrl: Interfaces.TelegramLoginUrl;
}
/** Inline keyboard */
export declare class InlineKeyboard {
    private buttons;
    get [Symbol.toStringTag](): string;
    /** Empty inline keyboard. That's literally it. */
    static empty: InlineKeyboard;
    /** Assemble a builder of buttons */
    static keyboard(rows: (Interfaces.TelegramInlineKeyboardButton | Interfaces.TelegramInlineKeyboardButton[])[]): InlineKeyboard;
    /** Generate text button */
    static textButton(params: TextButtonParams): Interfaces.TelegramInlineKeyboardButton;
    /** Generate URL button */
    static urlButton(params: UrlButtonParams): Interfaces.TelegramInlineKeyboardButton;
    /** Generate Web App button */
    static webAppButton(params: WebAppButtonParams): Interfaces.TelegramInlineKeyboardButton;
    /** Generate button that will switch to current chat and type the query */
    static switchToCurrentChatButton(params: SwitchToCurrentChatButtonParams): Interfaces.TelegramInlineKeyboardButton;
    /** Generate button that will prompt user to select one of their chats */
    static switchToChatButton(params: SwitchToChatButtonParams): Interfaces.TelegramInlineKeyboardButton;
    /** Generate button that will prompt user to select one of their chats of the specified type, open that chat and insert the bot's username and the specified inline query in the input field */
    static switchToChosenChatButton(params: SwitchToChosenChatButtonParams): Interfaces.TelegramInlineKeyboardButton;
    /** Generate game button */
    static gameButton(params: GameButtonParams): Interfaces.TelegramInlineKeyboardButton;
    /** Generate pay button */
    static payButton(params: PayButtonParams): Interfaces.TelegramInlineKeyboardButton;
    /** Generate login button */
    static loginButton(params: LoginButtonParams): Interfaces.TelegramInlineKeyboardButton;
    private addRow;
    /** Returns JSON which is compatible with Telegram's `InlineKeyboardMarkup` interface */
    toJSON(): Interfaces.TelegramInlineKeyboardMarkup;
    toString(): string;
}
export {};
