import * as Interfaces from '../../generated/telegram-interfaces';
import { MaybeArray } from '../../types/types';
import { RemoveKeyboard } from './remove';
/** Keyboard */
export declare class Keyboard {
    private buttons;
    private isResized;
    private isOneTime;
    private isSelective;
    private isPersistent;
    private placeholder?;
    get [Symbol.toStringTag](): string;
    /** Returns an "empty" keyboard (literally a `RemoveKeyboard` alias) */
    static empty: RemoveKeyboard;
    /** "Removes" a keyboard (literally a `RemoveKeyboard` alias) */
    static remove(): RemoveKeyboard;
    /** Assemble a builder of buttons */
    static keyboard(rows: MaybeArray<Interfaces.TelegramKeyboardButton | string>[]): Keyboard;
    /** Requests clients to resize the keyboard vertically for optimal fit (e.g., make the keyboard smaller if there are just two rows of buttons). Defaults to `false`, in which case the custom keyboard is always of the same height as the app's standard keyboard */
    resize(resize?: boolean): this;
    /** Requests clients to hide the keyboard as soon as it's been used. The keyboard will still be available, but clients will automatically display the usual letter-keyboard in the chat - the user can press a special button in the input field to see the custom keyboard again. Defaults to `false` */
    oneTime(oneTime?: boolean): this;
    /** Use this parameter if you want to show the keyboard to specific users only */
    selective(selective?: boolean): this;
    /** Requests clients to always show the keyboard when the regular keyboard is hidden. Defaults to `false`, in which case the custom keyboard can be hidden and opened with a keyboard icon */
    persistent(persistent?: boolean): this;
    /** The placeholder to be shown in the input field when the keyboard is active */
    setPlaceholder(placeholder: string): this;
    /**
     * Generates text button.
     * If none of the optional fields are used,
     * it will be sent as a message when the button is pressed
     */
    static textButton(text: string): Interfaces.TelegramKeyboardButton;
    /** If specified, pressing the button will open a list of suitable users. Tapping on any user will send their identifier to the bot in a “user_shared” service message. Available in private chats only. */
    static requestUsersButton(text: string, params: Interfaces.TelegramKeyboardButtonRequestUsers): Interfaces.TelegramKeyboardButton;
    /** If specified, pressing the button will open a list of suitable chats. Tapping on a chat will send its identifier to the bot in a “chat_shared” service message. Available in private chats only. */
    static requestChatButton(text: string, params: Interfaces.TelegramKeyboardButtonRequestChat): Interfaces.TelegramKeyboardButton;
    /**
     * The user's phone number will be sent as a contact when
     * the button is pressed.
     *
     * Available in private chats only
     */
    static requestContactButton(text: string): Interfaces.TelegramKeyboardButton;
    /**
     * The user's current location will be sent when the button is pressed.
     *
     * Available in private chats only
     */
    static requestLocationButton(text: string): Interfaces.TelegramKeyboardButton;
    /**
     * The user will be asked to create a poll and send it to the bot
     * when the button is pressed.
     *
     * Available in private chats only
     */
    static requestPollButton(text: string, type?: Interfaces.TelegramPoll['type']): Interfaces.TelegramKeyboardButton;
    /**
     * The described Web App will be launched when the button is pressed.
     * The Web App will be able to send a `web_app_data` service message.
     *
     * Available in private chats only.
     */
    static webAppButton(text: string, url: string): Interfaces.TelegramKeyboardButton;
    private addRow;
    /** Returns JSON which is compatible with Telegram's `ReplyKeyboardMarkup` interface */
    toJSON(): Interfaces.TelegramReplyKeyboardMarkup;
    toString(): string;
}
