import * as Contexts from '../contexts';
import * as Methods from '../generated/methods';
import { Telegram } from '../telegram';
import { Optional } from '../types/types';
interface MediaGroupOptions {
    id: string;
    contexts: Contexts.MessageContext[];
    telegram: Telegram;
}
/** This object represents a media group: a group of contexts with some attachments in it */
export declare class MediaGroup {
    private options;
    constructor(options: MediaGroupOptions);
    get [Symbol.toStringTag](): string;
    /** Returns media group's ID */
    get id(): string;
    /** Returns a list of contexts (constructed earlier) every single of which contains an attachment */
    get contexts(): Contexts.MessageContext[];
    /** Returns a list of attachments (mapped through `contexts`) */
    get attachments(): (import("./attachments").AnimationAttachment | import("./attachments").AudioAttachment | import("./attachments/contact").ContactAttachment | import("./attachments").DocumentAttachment | import("./attachments/location").LocationAttachment | import("./attachments").PhotoAttachment | import("./attachments").StickerAttachment | import("./attachments/story").StoryAttachment | import("./attachments").VideoAttachment | import("./attachments").VideoNoteAttachment | import("./attachments").VoiceAttachment | import("./attachments/poll").PollAttachment | import("./attachments/venue").VenueAttachment | undefined)[];
    /** Forwards a whole media group to `chatId` */
    forward(chatId?: string | number, params?: Optional<Methods.ForwardMessagesParams, 'chat_id' | 'from_chat_id' | 'message_ids'>): Promise<import("../generated").TelegramMessageId[]>;
    /** Copies a whole media group to `chatId` */
    copy(chatId?: string | number, params?: Optional<Methods.CopyMessagesParams, 'chat_id' | 'from_chat_id' | 'message_ids'>): Promise<import("../generated").TelegramMessageId[]>;
    /** Deletes whole media group */
    delete(params?: Optional<Methods.DeleteMessagesParams, 'chat_id' | 'message_ids'>): Promise<true>;
}
export {};
