"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MediaGroup = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
/** This object represents a media group: a group of contexts with some attachments in it */
let MediaGroup = class MediaGroup {
    constructor(options) {
        this.options = options;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Returns media group's ID */
    get id() {
        return this.options.id;
    }
    /** Returns a list of contexts (constructed earlier) every single of which contains an attachment */
    get contexts() {
        return this.options.contexts;
    }
    /** Returns a list of attachments (mapped through `contexts`) */
    get attachments() {
        const attachments = this.contexts.map(context => context.attachment);
        return attachments;
    }
    /** Forwards a whole media group to `chatId` */
    forward(chatId = this.contexts[0].chatId, params = {}) {
        return this.options.telegram.api.forwardMessages({
            chat_id: chatId,
            from_chat_id: this.contexts[0].chatId,
            message_ids: this.contexts.map(c => c.id),
            ...params
        });
    }
    /** Copies a whole media group to `chatId` */
    copy(chatId = this.contexts[0].chatId, params = {}) {
        return this.options.telegram.api.copyMessages({
            chat_id: chatId,
            from_chat_id: this.contexts[0].chatId,
            message_ids: this.contexts.map(c => c.id),
            ...params
        });
    }
    /** Deletes whole media group */
    delete(params = {}) {
        return this.options.telegram.api.deleteMessages({
            chat_id: this.contexts[0].chatId,
            message_ids: this.contexts.map(c => c.id),
            ...params
        });
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MediaGroup.prototype, "id", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MediaGroup.prototype, "contexts", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MediaGroup.prototype, "attachments", null);
MediaGroup = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], MediaGroup);
exports.MediaGroup = MediaGroup;
