import type { Known, MaybeArray } from '../types/types';
import * as Interfaces from '../generated/telegram-interfaces';
import { MessageEntity } from './structures';
/**
 * This class wraps basic array of `MessageEntity` and provides some methods
 * such as `has(type)` or `atOffset(index)` for easier workflow with entities
 *
 * @example
 * if (!context.entities.has(['bold', 'italic'])) {
 *   return context.reply('no bold/italic markdown found!')
 * }
 *
 * @example
 * const entities = context.entities.only('pre').with({ language: 'js' })
 * // can also be   context.entities.with({ type: 'pre', language: 'js' })
 *
 * if (entities.isEmpty()) {
 *   return context.send('no ```js tags found!')
 * }
 */
export declare class MessageEntities extends Array<MessageEntity> {
    constructor(...entities: MessageEntity[]);
    isEmpty(): boolean;
    get first(): MessageEntity | undefined;
    get last(): MessageEntity | undefined;
    has(type: MessageEntity['type']): boolean;
    only(type: MaybeArray<MessageEntity['type']>): MessageEntities;
    with(payload: Partial<Known<Interfaces.TelegramMessageEntity>>): MessageEntities;
    except(type: MaybeArray<MessageEntity['type']>): MessageEntities;
    without(payload: Partial<Known<Interfaces.TelegramMessageEntity>>): MessageEntities;
    atOffset(index: number): MessageEntities;
    toJSON(): Interfaces.TelegramMessageEntity[];
}
