"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatAdministratorRights = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
/** Represents the rights of an administrator in a chat. */
let ChatAdministratorRights = class ChatAdministratorRights {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** `true`, if the user's presence in the chat is hidden */
    isAnonymous() {
        return this.payload.is_anonymous;
    }
    /** `true`, if the administrator can access the chat event log, chat statistics, message statistics in channels, see channel members, see anonymous administrators in supergroups and ignore slow mode. Implied by any other administrator privilege */
    canManageChat() {
        return this.payload.can_manage_chat;
    }
    /** `true`, if the administrator can delete messages of other users */
    canDeleteMessages() {
        return this.payload.can_delete_messages;
    }
    /** `true`, if the administrator can manage video chats */
    canManageVideoChats() {
        return this.payload.can_manage_video_chats;
    }
    /** `true`, if the administrator can restrict, ban or unban chat members */
    canRestrictMembers() {
        return this.payload.can_restrict_members;
    }
    /** `true`, if the administrator can add new administrators with a subset of their own privileges or demote administrators that he has promoted, directly or indirectly (promoted by administrators that were appointed by the user) */
    canPromoteMembers() {
        return this.payload.can_promote_members;
    }
    /** `true`, if the user is allowed to change the chat title, photo and other settings */
    canChangeInfo() {
        return this.payload.can_change_info;
    }
    /** `true`, if the user is allowed to invite new users to the chat */
    canInviteUsers() {
        return this.payload.can_invite_users;
    }
    /** `true`, if the administrator can post in the channel; channels only */
    canPostMessages() {
        return this.payload.can_post_messages;
    }
    /** `true`, if the administrator can edit messages of other users and can pin messages; channels only */
    canEditMessages() {
        return this.payload.can_edit_messages;
    }
    /** `true`, if the user is allowed to pin messages; groups and supergroups only */
    canPinMessages() {
        return this.payload.can_pin_messages;
    }
    /** `true`, if the administrator can post stories in the channel; channels only */
    canPostStories() {
        return this.payload.can_post_stories;
    }
    /** `true`, if the administrator can edit stories posted by other users; channels only */
    canEditStories() {
        return this.payload.can_edit_stories;
    }
    /** `true`, if the administrator can delete stories posted by other users; channels only */
    canDeleteStories() {
        return this.payload.can_delete_stories;
    }
    /** `true`, if the user is allowed to create, rename, close, and reopen forum topics; supergroups only */
    canManageTopics() {
        return this.payload.can_manage_topics;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "isAnonymous", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canManageChat", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canDeleteMessages", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canManageVideoChats", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canRestrictMembers", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canPromoteMembers", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canChangeInfo", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canInviteUsers", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canPostMessages", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canEditMessages", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canPinMessages", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canPostStories", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canEditStories", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canDeleteStories", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], ChatAdministratorRights.prototype, "canManageTopics", null);
ChatAdministratorRights = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], ChatAdministratorRights);
exports.ChatAdministratorRights = ChatAdministratorRights;
