"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatBoostRemoved = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const chat_1 = require("./chat");
const chat_boost_source_1 = require("./chat-boost-source");
const helpers_1 = require("../../utils/helpers");
/** This object represents a boost added to a chat or changed. */
let ChatBoostRemoved = class ChatBoostRemoved {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Chat which was boosted */
    get chat() {
        return new chat_1.Chat(this.payload.chat);
    }
    /** Unique identifier of the boost */
    get id() {
        return this.payload.boost_id;
    }
    /** Point in time (Unix timestamp) when the boost was removed */
    get removeDate() {
        return this.payload.remove_date;
    }
    /** Source of the removed boost */
    get source() {
        if (this.payload.source.source === 'premium') {
            return new chat_boost_source_1.ChatBoostSourcePremium(this.payload.source);
        }
        if (this.payload.source.source === 'gift_code') {
            return new chat_boost_source_1.ChatBoostSourceGiftCode(this.payload.source);
        }
        if (this.payload.source.source === 'giveaway') {
            return new chat_boost_source_1.ChatBoostSourceGiveaway(this.payload.source);
        }
        throw new TypeError('unknown chat boost source');
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatBoostRemoved.prototype, "chat", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatBoostRemoved.prototype, "id", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatBoostRemoved.prototype, "removeDate", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatBoostRemoved.prototype, "source", null);
ChatBoostRemoved = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], ChatBoostRemoved);
exports.ChatBoostRemoved = ChatBoostRemoved;
(0, helpers_1.memoizeGetters)(ChatBoostRemoved, ['chat', 'source']);
