"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatBoostSourceGiveaway = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const user_1 = require("../user");
const chat_boost_source_1 = require("./chat-boost-source");
const helpers_1 = require("../../../utils/helpers");
/** The boost was obtained by the creation of a Telegram Premium giveaway. This boosts the chat 4 times for the duration of the corresponding Telegram Premium subscription. */
let ChatBoostSourceGiveaway = class ChatBoostSourceGiveaway extends chat_boost_source_1.ChatBoostSource {
    constructor(payload) {
        super(payload);
        this.payload = payload;
    }
    /** Source of the boost, always `giveaway` */
    get source() {
        return this.payload.source;
    }
    get giveawayMessageId() {
        return this.payload.giveaway_message_id;
    }
    /** User that boosted the chat */
    get user() {
        const { user } = this.payload;
        if (!user) {
            return;
        }
        return new user_1.User(user);
    }
    /** `true`, if the giveaway was completed, but there was no user to win the prize */
    isUnclaimed() {
        return this.payload.is_unclaimed;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatBoostSourceGiveaway.prototype, "source", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ChatBoostSourceGiveaway.prototype, "user", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], ChatBoostSourceGiveaway.prototype, "isUnclaimed", null);
ChatBoostSourceGiveaway = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], ChatBoostSourceGiveaway);
exports.ChatBoostSourceGiveaway = ChatBoostSourceGiveaway;
(0, helpers_1.memoizeGetters)(ChatBoostSourceGiveaway, ['user']);
