"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatBoost = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const chat_boost_source_1 = require("./chat-boost-source");
const helpers_1 = require("../../utils/helpers");
/** This object contains information about a chat boost. */
let ChatBoost = class ChatBoost {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Unique identifier of the boost */
    get id() {
        return this.payload.boost_id;
    }
    /** Point in time (Unix timestamp) when the chat was boosted */
    get addDate() {
        return this.payload.add_date;
    }
    /** Point in time (Unix timestamp) when the boost will automatically expire, unless the booster's Telegram Premium subscription is prolonged */
    get expirationDate() {
        return this.payload.expiration_date;
    }
    /** Source of the added boost */
    get source() {
        if (this.payload.source.source === 'premium') {
            return new chat_boost_source_1.ChatBoostSourcePremium(this.payload.source);
        }
        if (this.payload.source.source === 'gift_code') {
            return new chat_boost_source_1.ChatBoostSourceGiftCode(this.payload.source);
        }
        if (this.payload.source.source === 'giveaway') {
            return new chat_boost_source_1.ChatBoostSourceGiveaway(this.payload.source);
        }
        throw new TypeError('unknown chat boost source');
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatBoost.prototype, "id", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatBoost.prototype, "addDate", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatBoost.prototype, "expirationDate", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatBoost.prototype, "source", null);
ChatBoost = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], ChatBoost);
exports.ChatBoost = ChatBoost;
(0, helpers_1.memoizeGetters)(ChatBoost, ['source']);
