import * as Interfaces from '../../generated/telegram-interfaces';
import { Structure } from '../../types/interfaces';
import { User } from './user';
/** Represents an invite link for a chat. */
export declare class ChatInviteLink implements Structure {
    payload: Interfaces.TelegramChatInviteLink;
    constructor(payload: Interfaces.TelegramChatInviteLink);
    get [Symbol.toStringTag](): string;
    /**
     * The invite link. If the link was created by another chat administrator,
     * then the second part of the link will be replaced with `…`.
     */
    get link(): string;
    /** Creator of the link */
    get creator(): User;
    /** Invite link name */
    get name(): string | undefined;
    /** `true`, if the link is primary */
    isPrimary(): boolean;
    /** `true`, if the link is revoked */
    isRevoked(): boolean;
    /** Point in time (Unix timestamp) when the link will expire or has been expired */
    get expireDate(): number | undefined;
    /**
     * Maximum number of users that can be members of the chat simultaneously
     * after joining the chat via this invite link;
     * `1-99999`
     */
    get memberLimit(): number | undefined;
    /** `true`, if users joining the chat via the link need to be approved by chat administrators */
    get createsJoinRequest(): boolean;
    /** Number of pending join requests created using this link */
    get pendingJoinRequestCount(): number | undefined;
    toJSON(): Interfaces.TelegramChatInviteLink;
}
