"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatMemberUpdated = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const chat_1 = require("./chat");
const chat_invite_link_1 = require("./chat-invite-link");
const chat_member_1 = require("./chat-member");
const user_1 = require("./user");
const helpers_1 = require("../../utils/helpers");
/** This object represents changes in the status of a chat member. */
let ChatMemberUpdated = class ChatMemberUpdated {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Chat the user belongs to */
    get chat() {
        return new chat_1.Chat(this.payload.chat);
    }
    /** Performer of the action, which resulted in the change */
    get from() {
        return new user_1.User(this.payload.from);
    }
    /** Date the change was done in Unix time */
    get date() {
        return this.payload.date;
    }
    /** Previous information about the chat member */
    get oldChatMember() {
        return new chat_member_1.ChatMember(this.payload.old_chat_member);
    }
    /** New information about the chat member */
    get newChatMember() {
        return new chat_member_1.ChatMember(this.payload.new_chat_member);
    }
    /**
     * Chat invite link, which was used by the user to join the chat;
     * for joining by invite link events only.
     */
    get inviteLink() {
        const { invite_link } = this.payload;
        if (!invite_link) {
            return;
        }
        return new chat_invite_link_1.ChatInviteLink(invite_link);
    }
    /** `true`, if the user joined the chat via a chat folder invite link */
    get viaChatFolderInviteLink() {
        return this.payload.via_chat_folder_invite_link;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatMemberUpdated.prototype, "chat", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatMemberUpdated.prototype, "from", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatMemberUpdated.prototype, "date", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatMemberUpdated.prototype, "oldChatMember", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatMemberUpdated.prototype, "newChatMember", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ChatMemberUpdated.prototype, "inviteLink", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ChatMemberUpdated.prototype, "viaChatFolderInviteLink", null);
ChatMemberUpdated = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], ChatMemberUpdated);
exports.ChatMemberUpdated = ChatMemberUpdated;
(0, helpers_1.memoizeGetters)(ChatMemberUpdated, ['chat', 'from', 'oldChatMember', 'newChatMember', 'inviteLink']);
