import * as Interfaces from '../../generated/telegram-interfaces';
import { Structure } from '../../types/interfaces';
import { User } from './user';
/**
 * This object contains information about one member of a chat. Currently, the following 6 types of chat members are supported:
 * - `ChatMemberOwner`
 * - `ChatMemberAdministrator`
 * - `ChatMemberMember`
 * - `ChatMemberRestricted`
 * - `ChatMemberLeft`
 * - `ChatMemberBanned`
 */
export declare class ChatMember implements Structure {
    payload: Interfaces.TelegramChatMember;
    constructor(payload: Interfaces.TelegramChatMember);
    get [Symbol.toStringTag](): string;
    /** Information about the user */
    get user(): User;
    /** The member's status in the chat */
    get status(): "creator" | import("../..").ChatMemberStatus | "administrator" | "member" | "restricted" | "left" | "kicked";
    /** Owner and administrators only. Custom title for this user */
    get customTitle(): string | undefined;
    /** Owner and administrators only. `true`, if the user's presence in the chat is hidden */
    isAnonymous(): boolean | undefined;
    /**
     * Restricted and kicked only.
     * Date when restrictions will be lifted for this user;
     * unix time
     */
    get untilDate(): number | undefined;
    /**
     * Administrators only.
     * `true`, if the bot is allowed to edit administrator privileges of that
     * user
     */
    canBeEdited(): boolean | undefined;
    /**
     * Administrators only.
     * `true`, if the administrator can access the chat event log, chat statistics,
     * message statistics in channels, see channel members, see anonymous administrators
     * in supergroups and ignore slow mode.
     * Implied by any other administrator privilege
     */
    canManageChat(): boolean | undefined;
    /**
     * Administrators only.
     * `true`, if the administrator can post in the channel;
     * channels only
     */
    canPostMessages(): boolean | undefined;
    /**
     * Administrators only.
     * `true`, if the administrator can edit messages of other users
     * and can pin messages; channels only
     */
    canEditMessages(): boolean | undefined;
    /**
     * Administrators only.
     * `true`, if the administrator can delete messages of other users
     */
    canDeleteMessages(): boolean | undefined;
    /**
     * Administrators only.
     * `true`, if the administrator can manage video chats
     */
    canManageVideoChats(): boolean | undefined;
    /**
     * Administrators only.
     * `true`, if the administrator can restrict, ban or unban chat members
     */
    canRestrictMembers(): boolean | undefined;
    /**
     * Administrators only.
     * `true`, if the administrator can add new administrators with a subset o
     * their own privileges or demote administrators that he has promoted,
     * directly or indirectly (promoted by administrators that were appointed by
     * the user)
     */
    canPromoteMembers(): boolean | undefined;
    /**
     * Administrators and restricted only.
     * `true`, if the user is allowed to change the chat title,
     * photo and other settings
     */
    canChangeInfo(): boolean | undefined;
    /**
     * Administrators and restricted only.
     * `true`, if the user is allowed to invite new users to the chat
     */
    canInviteUsers(): boolean | undefined;
    /**
     * Administrators and restricted only.
     * `true`, if the user is allowed to pin messages;
     * groups and supergroups only
     */
    canPinMessages(): boolean | undefined;
    /** `true`, if the administrator can post stories in the channel; channels only */
    canPostStories(): any;
    /** `true`, if the administrator can edit stories posted by other users; channels only */
    canEditStories(): any;
    /** `true`, if the administrator can delete stories posted by other users; channels only */
    canDeleteStories(): any;
    /** `true`, if the user is allowed to create, rename, close, and reopen forum topics; supergroups only */
    canManageTopics(): boolean | undefined;
    /**
     * Restricted only.
     * `true`, if the user is a member of the chat at the moment of the request
     */
    isMember(): boolean | undefined;
    /**
     * Restricted only.
     * `true`, if the user is allowed to send text messages,
     * contacts, locations and venues
     */
    canSendMessages(): boolean | undefined;
    /** `true`, if the user is allowed to send audios */
    canSendAudios(): boolean | undefined;
    /** `true`, if the user is allowed to send documents */
    canSendDocuments(): boolean | undefined;
    /** `true`, if the user is allowed to send photos */
    canSendPhotos(): boolean | undefined;
    /** `true`, if the user is allowed to send videos */
    canSendVideos(): boolean | undefined;
    /** `true`, if the user is allowed to send video notes */
    canSendVideoNotes(): boolean | undefined;
    /** `true`, if the user is allowed to send voice notes */
    canSendVoiceNotes(): boolean | undefined;
    /** Restricted only. `true`, if the user is allowed to send polls */
    canSendPolls(): boolean | undefined;
    /**
     * Restricted only.
     * `true`, if the user is allowed to send animations, games,
     * stickers and use inline bots
     */
    canSendOtherMessages(): boolean | undefined;
    /**
     * Restricted only
     * `true`, if the user is allowed to add web page previews to their messages
     */
    canAddWebPagePreviews(): boolean | undefined;
    toJSON(): Interfaces.TelegramChatMember;
}
