import * as Interfaces from '../../generated/telegram-interfaces';
import { Structure } from '../../types/interfaces';
/**
 * Describes actions that a non-administrator user is allowed to take in a
 * chat.
 */
export declare class ChatPermissions implements Structure {
    payload: Interfaces.TelegramChatPermissions;
    constructor(payload: Interfaces.TelegramChatPermissions);
    get [Symbol.toStringTag](): string;
    /**
     * `true`, if the user is allowed to send text messages, contacts, locations
     * and venues
     */
    canSendMessages(): boolean | undefined;
    /**
     * `true`, if the user is allowed to send audios, documents, photos, videos,
     * video notes and voice notes, implies `can_send_messages`
     */
    canSendMediaMessages(): boolean | undefined;
    /**
     * `true`, if the user is allowed to send polls, implies `can_send_messages`
     */
    canSendPolls(): boolean | undefined;
    /**
     * `true`, if the user is allowed to send animations, games, stickers and use
     * inline bots, implies `can_send_media_messages`
     */
    canSendOtherMessages(): boolean | undefined;
    /**
     * `true`, if the user is allowed to add web page previews to their messages,
     * implies `can_send_media_messages`
     */
    canAddWebPagePreviews(): boolean | undefined;
    /**
     * `true`, if the user is allowed to change the chat title, photo and other
     * settings. Ignored in public supergroups
     */
    canChangeInfo(): boolean | undefined;
    /** `true`, if the user is allowed to invite new users to the chat */
    canInviteUsers(): boolean | undefined;
    /**
     * `true`, if the user is allowed to pin messages. Ignored in public
     * supergroups
     */
    canPinMessages(): boolean | undefined;
    /** `true`, if the user is allowed to create forum topics. If omitted defaults to the value of can_pin_messages */
    canManageTopics(): boolean | undefined;
    toJSON(): Interfaces.TelegramChatPermissions;
}
