"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatPermissions = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
/**
 * Describes actions that a non-administrator user is allowed to take in a
 * chat.
 */
let ChatPermissions = class ChatPermissions {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /**
     * `true`, if the user is allowed to send text messages, contacts, locations
     * and venues
     */
    canSendMessages() {
        return this.payload.can_send_messages;
    }
    /**
     * `true`, if the user is allowed to send audios, documents, photos, videos,
     * video notes and voice notes, implies `can_send_messages`
     */
    canSendMediaMessages() {
        return this.payload.can_send_media_messages;
    }
    /**
     * `true`, if the user is allowed to send polls, implies `can_send_messages`
     */
    canSendPolls() {
        return this.payload.can_send_polls;
    }
    /**
     * `true`, if the user is allowed to send animations, games, stickers and use
     * inline bots, implies `can_send_media_messages`
     */
    canSendOtherMessages() {
        return this.payload.can_send_other_messages;
    }
    /**
     * `true`, if the user is allowed to add web page previews to their messages,
     * implies `can_send_media_messages`
     */
    canAddWebPagePreviews() {
        return this.payload.can_add_web_page_previews;
    }
    /**
     * `true`, if the user is allowed to change the chat title, photo and other
     * settings. Ignored in public supergroups
     */
    canChangeInfo() {
        return this.payload.can_change_info;
    }
    /** `true`, if the user is allowed to invite new users to the chat */
    canInviteUsers() {
        return this.payload.can_invite_users;
    }
    /**
     * `true`, if the user is allowed to pin messages. Ignored in public
     * supergroups
     */
    canPinMessages() {
        return this.payload.can_pin_messages;
    }
    /** `true`, if the user is allowed to create forum topics. If omitted defaults to the value of can_pin_messages */
    canManageTopics() {
        return this.payload.can_manage_topics;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], ChatPermissions.prototype, "canSendMessages", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], ChatPermissions.prototype, "canSendMediaMessages", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], ChatPermissions.prototype, "canSendPolls", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], ChatPermissions.prototype, "canSendOtherMessages", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], ChatPermissions.prototype, "canAddWebPagePreviews", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], ChatPermissions.prototype, "canChangeInfo", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], ChatPermissions.prototype, "canInviteUsers", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], ChatPermissions.prototype, "canPinMessages", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], ChatPermissions.prototype, "canManageTopics", null);
ChatPermissions = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], ChatPermissions);
exports.ChatPermissions = ChatPermissions;
