"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatPhoto = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
/** This object represents a chat photo. */
let ChatPhoto = class ChatPhoto {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /**
     * File identifier of small (`160x160`) chat photo.
     * This `file_id` can be used only for photo download and only for as long
     * as the photo is not changed.
     */
    get smallFileId() {
        return this.payload.small_file_id;
    }
    /**
     * Unique file identifier of small (`160x160`) chat photo, which is supposed
     * to be the same over time and for different bots. Can't be used to download
     * or reuse the file.
     */
    get smallFileUniqueId() {
        return this.payload.small_file_unique_id;
    }
    /**
     * File identifier of big (`640x640`) chat photo. This `file_id` can be used
     * only for photo download and only for as long as the photo is not changed.
     */
    get bigFileId() {
        return this.payload.big_file_id;
    }
    /**
     * Unique file identifier of big (`640x640`) chat photo, which is supposed
     * to be the same over time and for different bots. Can't be used to
     * download or reuse the file.
     */
    get bigFileUniqueId() {
        return this.payload.big_file_unique_id;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatPhoto.prototype, "smallFileId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatPhoto.prototype, "smallFileUniqueId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatPhoto.prototype, "bigFileId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChatPhoto.prototype, "bigFileUniqueId", null);
ChatPhoto = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], ChatPhoto);
exports.ChatPhoto = ChatPhoto;
