"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChosenInlineResult = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const user_1 = require("./user");
const location_1 = require("./location");
const helpers_1 = require("../../utils/helpers");
/** Represents a result of an inline query that was chosen by the user and sent to their chat partner. */
let ChosenInlineResult = class ChosenInlineResult {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** The unique identifier for the result that was chosen */
    get resultId() {
        return this.payload.result_id;
    }
    /** The user that chose the result */
    get from() {
        return new user_1.User(this.payload.from);
    }
    /** Sender ID */
    get senderId() {
        return this.from.id;
    }
    /** Sender location, only for bots that require user location */
    get location() {
        const { location } = this.payload;
        if (!location) {
            return;
        }
        return new location_1.Location(location);
    }
    /**
     * Identifier of the sent inline message. Available only if there is an
     * inline keyboard attached to the message. Will be also received in callback
     * queries and can be used to edit the message.
     */
    get inlineMessageId() {
        return this.payload.inline_message_id;
    }
    /** The query that was used to obtain the result */
    get query() {
        return this.payload.query;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChosenInlineResult.prototype, "resultId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChosenInlineResult.prototype, "from", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChosenInlineResult.prototype, "senderId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ChosenInlineResult.prototype, "location", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], ChosenInlineResult.prototype, "inlineMessageId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ChosenInlineResult.prototype, "query", null);
ChosenInlineResult = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], ChosenInlineResult);
exports.ChosenInlineResult = ChosenInlineResult;
(0, helpers_1.memoizeGetters)(ChosenInlineResult, ['from', 'location']);
