"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EncryptedCredentials = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
/**
 * Contains data required for decrypting and authenticatin
 * `EncryptedPassportElement`. See the Telegram Passport Documentation for a
 * complete description of the data decryption and authentication processes.
 */
let EncryptedCredentials = class EncryptedCredentials {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /**
     * Base64-encoded encrypted JSON-serialized data with unique user's payload,
     * data hashes and secrets required for `EncryptedPassportElement` decryption
     * and authentication
     */
    get data() {
        return this.payload.data;
    }
    /** Base64-encoded data hash for data authentication */
    get hash() {
        return this.payload.hash;
    }
    /**
     * Base64-encoded secret, encrypted with the bot's public RSA key, required
     * for data decryption
     */
    get secret() {
        return this.payload.secret;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], EncryptedCredentials.prototype, "data", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], EncryptedCredentials.prototype, "hash", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], EncryptedCredentials.prototype, "secret", null);
EncryptedCredentials = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], EncryptedCredentials);
exports.EncryptedCredentials = EncryptedCredentials;
