import * as Interfaces from '../../generated/telegram-interfaces';
import { Structure } from '../../types/interfaces';
/** This object represents a file ready to be downloaded. The file can be downloaded via the link `https://api.telegram.org/file/bot<token>/<file_path>`. It is guaranteed that the link will be valid for at least 1 hour. When the link expires, a new one can be requested by calling `getFile`. */
export declare class File implements Structure {
    payload: Interfaces.TelegramFile;
    constructor(payload: Interfaces.TelegramFile);
    get [Symbol.toStringTag](): string;
    /**
     * Identifier for this file, which can be used to download or reuse the file
     */
    get fileId(): string;
    /**
     * Unique identifier for this file, which is supposed to be the same over
     * time and for different bots. Can't be used to download or reuse the file.
     */
    get fileUniqueId(): string;
    /** File size, if known */
    get fileSize(): number | undefined;
    /**
     * File path.
     * Use `https://api.telegram.org/file/bot<token>/<file_path>` to get the
     * file.
     */
    get filePath(): string | undefined;
    toJSON(): Interfaces.TelegramFile;
}
