"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.File = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
/** This object represents a file ready to be downloaded. The file can be downloaded via the link `https://api.telegram.org/file/bot<token>/<file_path>`. It is guaranteed that the link will be valid for at least 1 hour. When the link expires, a new one can be requested by calling `getFile`. */
let File = class File {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /**
     * Identifier for this file, which can be used to download or reuse the file
     */
    get fileId() {
        return this.payload.file_id;
    }
    /**
     * Unique identifier for this file, which is supposed to be the same over
     * time and for different bots. Can't be used to download or reuse the file.
     */
    get fileUniqueId() {
        return this.payload.file_unique_id;
    }
    /** File size, if known */
    get fileSize() {
        return this.payload.file_size;
    }
    /**
     * File path.
     * Use `https://api.telegram.org/file/bot<token>/<file_path>` to get the
     * file.
     */
    get filePath() {
        return this.payload.file_path;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], File.prototype, "fileId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], File.prototype, "fileUniqueId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], File.prototype, "fileSize", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], File.prototype, "filePath", null);
File = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], File);
exports.File = File;
