import * as Interfaces from '../../generated/telegram-interfaces';
import { Structure } from '../../types/interfaces';
import { AnimationAttachment } from '../attachments';
import { PhotoSize } from './photo-size';
import { MessageEntities } from '../message-entities';
/** This object represents a game. */
export declare class Game implements Structure {
    payload: Interfaces.TelegramGame;
    constructor(payload: Interfaces.TelegramGame);
    get [Symbol.toStringTag](): string;
    /** Title of the game */
    get title(): string;
    /** Description of the game */
    get description(): string;
    /** Photo that will be displayed in the game message in chats. */
    get photo(): PhotoSize[] | undefined;
    /**
     * Brief description of the game or high scores included in the game message
     * Can be automatically edited to include current high scores for the game
     * when the bot calls `setGameScore`, or manually edited using
     * `editMessageText`. 0-4096 characters.
     */
    get text(): string | undefined;
    /**
     * Special entities that appear in text, such as usernames, URLs, bot
     * commands, etc.
     */
    get textEntities(): MessageEntities | undefined;
    /**
     * Animation that will be displayed in the game message in chats.
     * Upload via BotFather
     */
    get animation(): AnimationAttachment | undefined;
    toJSON(): Interfaces.TelegramGame;
}
