"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GiveawayCompleted = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const message_1 = require("./message");
const helpers_1 = require("../../utils/helpers");
/** This object represents a service message about the completion of a giveaway without public winners. */
let GiveawayCompleted = class GiveawayCompleted {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Number of winners in the giveaway */
    get winnerCount() {
        return this.payload.winner_count;
    }
    /** Number of undistributed prizes */
    get unclaimedPrizeCount() {
        return this.payload.unclaimed_prize_count;
    }
    /** Message with the giveaway that was completed, if it wasn't deleted */
    get message() {
        const { giveaway_message } = this.payload;
        if (!giveaway_message) {
            return;
        }
        return new message_1.Message(giveaway_message);
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], GiveawayCompleted.prototype, "winnerCount", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], GiveawayCompleted.prototype, "unclaimedPrizeCount", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], GiveawayCompleted.prototype, "message", null);
GiveawayCompleted = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], GiveawayCompleted);
exports.GiveawayCompleted = GiveawayCompleted;
(0, helpers_1.memoizeGetters)(GiveawayCompleted, ['message']);
