import * as Interfaces from '../../generated/telegram-interfaces';
import { Structure } from '../../types/interfaces';
import { Chat } from './chat';
/** This object represents a message about a scheduled giveaway. */
export declare class Giveaway implements Structure {
    payload: Interfaces.TelegramGiveaway;
    constructor(payload: Interfaces.TelegramGiveaway);
    get [Symbol.toStringTag](): string;
    /** The list of chats which the user must join to participate in the giveaway */
    get chats(): Chat[];
    /** Point in time (Unix timestamp) when winners of the giveaway will be selected */
    get winnersSelectionDate(): number;
    /** The number of users which are supposed to be selected as winners of the giveaway */
    get winnerCount(): number;
    /** `true`, if only users who join the chats after the giveaway started should be eligible to win */
    get onlyNewMembers(): true | undefined;
    /** `true`, if the list of giveaway winners will be visible to everyone */
    hasPublicWinners(): any;
    /** Description of additional giveaway prize */
    get prizeDescription(): string | undefined;
    /** A list of two-letter ISO 3166-1 alpha-2 country codes indicating the countries from which eligible users for the giveaway must come. If empty, then all users can participate in the giveaway. Users with a phone number that was bought on Fragment can always participate in giveaways. */
    get countryCodes(): string[] | undefined;
    /** The number of months the Telegram Premium subscription won from the giveaway will be active for */
    get premiumSubscriptionMonthCount(): number | undefined;
    toJSON(): Record<string, any>;
}
