"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Giveaway = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const chat_1 = require("./chat");
/** This object represents a message about a scheduled giveaway. */
let Giveaway = class Giveaway {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** The list of chats which the user must join to participate in the giveaway */
    get chats() {
        return this.payload.chats.map(c => new chat_1.Chat(c));
    }
    /** Point in time (Unix timestamp) when winners of the giveaway will be selected */
    get winnersSelectionDate() {
        return this.payload.winners_selection_date;
    }
    /** The number of users which are supposed to be selected as winners of the giveaway */
    get winnerCount() {
        return this.payload.winner_count;
    }
    /** `true`, if only users who join the chats after the giveaway started should be eligible to win */
    get onlyNewMembers() {
        return this.payload.only_new_members;
    }
    /** `true`, if the list of giveaway winners will be visible to everyone */
    hasPublicWinners() {
        return this.payload.public_winners;
    }
    /** Description of additional giveaway prize */
    get prizeDescription() {
        return this.payload.prize_description;
    }
    /** A list of two-letter ISO 3166-1 alpha-2 country codes indicating the countries from which eligible users for the giveaway must come. If empty, then all users can participate in the giveaway. Users with a phone number that was bought on Fragment can always participate in giveaways. */
    get countryCodes() {
        return this.payload.country_codes;
    }
    /** The number of months the Telegram Premium subscription won from the giveaway will be active for */
    get premiumSubscriptionMonthCount() {
        return this.payload.premium_subscription_month_count;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Giveaway.prototype, "chats", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Giveaway.prototype, "winnersSelectionDate", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Giveaway.prototype, "winnerCount", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Giveaway.prototype, "onlyNewMembers", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], Giveaway.prototype, "hasPublicWinners", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Giveaway.prototype, "prizeDescription", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Giveaway.prototype, "countryCodes", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Giveaway.prototype, "premiumSubscriptionMonthCount", null);
Giveaway = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], Giveaway);
exports.Giveaway = Giveaway;
