"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InlineQuery = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const user_1 = require("./user");
const location_1 = require("./location");
const helpers_1 = require("../../utils/helpers");
/**
 * This object represents an incoming inline query.
 * When the user sends an empty query, your bot could return some default or
 * trending results.
 */
let InlineQuery = class InlineQuery {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Unique identifier for this query */
    get id() {
        return this.payload.id;
    }
    /** Sender */
    get from() {
        return new user_1.User(this.payload.from);
    }
    /** Sender location, only for bots that request user location */
    get location() {
        const { location } = this.payload;
        if (!location) {
            return;
        }
        return new location_1.Location(location);
    }
    /** Text of the query (up to 256 characters) */
    get query() {
        return this.payload.query;
    }
    /** Offset of the results to be returned, can be controlled by the bot */
    get offset() {
        return this.payload.offset;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], InlineQuery.prototype, "id", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], InlineQuery.prototype, "from", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], InlineQuery.prototype, "location", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], InlineQuery.prototype, "query", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], InlineQuery.prototype, "offset", null);
InlineQuery = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], InlineQuery);
exports.InlineQuery = InlineQuery;
(0, helpers_1.memoizeGetters)(InlineQuery, ['from', 'location']);
