"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Location = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
/** This object represents a point on the map. */
let Location = class Location {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Longitude as defined by sender */
    get longitude() {
        return this.payload.longitude;
    }
    /** Latitude as defined by sender */
    get latitude() {
        return this.payload.latitude;
    }
    /** The radius of uncertainty for the location, measured in meters; `0-1500` */
    get horizontalAccuracy() {
        return this.payload.horizontal_accuracy;
    }
    /**
     * Time relative to the message sending date,
     * during which the location can be updated, in seconds.
     * For active live locations only.
     */
    get livePeriod() {
        return this.payload.live_period;
    }
    /**
     * The direction in which user is moving, in degrees; `1-360`.
     * For active live locations only.
     */
    get heading() {
        return this.payload.heading;
    }
    /**
     * Maximum distance for proximity alerts about approaching another chat member, in meters.
     * For sent live locations only.
     */
    get proximityAlertRadius() {
        return this.payload.proximity_alert_radius;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Location.prototype, "longitude", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Location.prototype, "latitude", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Location.prototype, "horizontalAccuracy", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Location.prototype, "livePeriod", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Location.prototype, "heading", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Location.prototype, "proximityAlertRadius", null);
Location = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], Location);
exports.Location = Location;
