"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MenuButton = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const web_app_info_1 = require("./web-app-info");
const helpers_1 = require("../../utils/helpers");
/** This object describes the bot's menu button in a private chat. */
let MenuButton = class MenuButton {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Type of the button */
    get type() {
        return this.payload.type;
    }
    /** Text on the button */
    get text() {
        return this.payload.text;
    }
    /**
     * Description of the Web App that will be launched when the user presses the button.
     * The Web App will be able to send an arbitrary message on behalf of the user
     * using the method `answerWebAppQuery`.
     */
    get webApp() {
        const { web_app } = this.payload;
        if (!web_app) {
            return;
        }
        return new web_app_info_1.WebAppInfo(web_app);
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MenuButton.prototype, "type", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MenuButton.prototype, "text", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], MenuButton.prototype, "webApp", null);
MenuButton = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], MenuButton);
exports.MenuButton = MenuButton;
(0, helpers_1.memoizeGetters)(MenuButton, ['webApp']);
