"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageOriginChannel = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const chat_1 = require("../chat");
const message_origin_1 = require("./message-origin");
const helpers_1 = require("../../../utils/helpers");
/** The message was originally sent to a channel chat. */
let MessageOriginChannel = class MessageOriginChannel extends message_origin_1.MessageOrigin {
    constructor(payload) {
        super(payload);
        this.payload = payload;
    }
    /** Type of the message origin, always `channel` */
    get type() {
        return this.payload.type;
    }
    /** Date the message was sent originally in Unix time */
    get date() {
        return this.payload.date;
    }
    /** Channel chat to which the message was originally sent */
    get chat() {
        return new chat_1.Chat(this.payload.chat);
    }
    /** Unique message identifier inside the chat */
    get messageId() {
        return this.payload.message_id;
    }
    /** Signature of the original post author */
    get authorSignature() {
        return this.payload.author_signature;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageOriginChannel.prototype, "type", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageOriginChannel.prototype, "date", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageOriginChannel.prototype, "chat", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageOriginChannel.prototype, "messageId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageOriginChannel.prototype, "authorSignature", null);
MessageOriginChannel = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], MessageOriginChannel);
exports.MessageOriginChannel = MessageOriginChannel;
(0, helpers_1.memoizeGetters)(MessageOriginChannel, ['chat']);
