"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageOriginChat = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const chat_1 = require("../chat");
const message_origin_1 = require("./message-origin");
const helpers_1 = require("../../../utils/helpers");
/** The message was originally sent on behalf of a chat to a group chat. */
let MessageOriginChat = class MessageOriginChat extends message_origin_1.MessageOrigin {
    constructor(payload) {
        super(payload);
        this.payload = payload;
    }
    /** Type of the message origin, always `chat` */
    get type() {
        return this.payload.type;
    }
    /** Date the message was sent originally in Unix time */
    get date() {
        return this.payload.date;
    }
    /** Chat that sent the message originally */
    get senderChat() {
        return new chat_1.Chat(this.payload.sender_chat);
    }
    /** For messages originally sent by an anonymous chat administrator, original message author signature */
    get authorSignature() {
        return this.payload.author_signature;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageOriginChat.prototype, "type", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageOriginChat.prototype, "date", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageOriginChat.prototype, "senderChat", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], MessageOriginChat.prototype, "authorSignature", null);
MessageOriginChat = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], MessageOriginChat);
exports.MessageOriginChat = MessageOriginChat;
(0, helpers_1.memoizeGetters)(MessageOriginChat, ['senderChat']);
