"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageReactionCountUpdated = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const chat_1 = require("./chat");
const reaction_type_1 = require("./reaction-type");
const helpers_1 = require("../../utils/helpers");
/** This object represents reaction changes on a message with anonymous reactions. */
let MessageReactionCountUpdated = class MessageReactionCountUpdated {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** The chat containing the message the user reacted to */
    get chat() {
        return new chat_1.Chat(this.payload.chat);
    }
    /** Unique identifier of the message inside the chat */
    get id() {
        return this.payload.message_id;
    }
    /** Date of the change in Unix time */
    get date() {
        return this.payload.date;
    }
    /** List of reactions that are present on the message */
    get reactions() {
        const reactions = [];
        for (const reaction of this.payload.reactions) {
            if (reaction.type.type === 'emoji') {
                reactions.push(new reaction_type_1.ReactionTypeEmoji(reaction.type));
            }
            else if (reaction.type.type === 'custom_emoji') {
                reactions.push(new reaction_type_1.ReactionTypeCustomEmoji(reaction.type));
            }
            else {
                throw new TypeError('unknown reaction type');
            }
        }
        return reactions;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageReactionCountUpdated.prototype, "chat", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageReactionCountUpdated.prototype, "id", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageReactionCountUpdated.prototype, "date", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageReactionCountUpdated.prototype, "reactions", null);
MessageReactionCountUpdated = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], MessageReactionCountUpdated);
exports.MessageReactionCountUpdated = MessageReactionCountUpdated;
(0, helpers_1.memoizeGetters)(MessageReactionCountUpdated, ['chat']);
