"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageReactionUpdated = void 0;
const tslib_1 = require("tslib");
const user_1 = require("./user");
const chat_1 = require("./chat");
const inspectable_1 = require("inspectable");
const helpers_1 = require("../../utils/helpers");
/** This object represents a change of a reaction on a message performed by a user. */
let MessageReactionUpdated = class MessageReactionUpdated {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** The chat containing the message the user reacted to */
    get chat() {
        return new chat_1.Chat(this.payload.chat);
    }
    /** Unique identifier of the message inside the chat */
    get id() {
        return this.payload.message_id;
    }
    /** The user that changed the reaction, if the user isn't anonymous */
    get user() {
        const { user } = this.payload;
        if (!user) {
            return;
        }
        return new user_1.User(user);
    }
    /** The chat on behalf of which the reaction was changed, if the user is anonymous */
    get actorChat() {
        const { actor_chat } = this.payload;
        if (!actor_chat) {
            return;
        }
        return new chat_1.Chat(actor_chat);
    }
    /** Date of the change in Unix time */
    get date() {
        return this.payload.date;
    }
    /** Previous list of reaction types that were set by the user */
    get oldReactions() {
        return this.payload.old_reaction;
    }
    /** New list of reaction types that have been set by the user */
    get newReactions() {
        return this.payload.new_reaction;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageReactionUpdated.prototype, "chat", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageReactionUpdated.prototype, "id", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], MessageReactionUpdated.prototype, "user", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], MessageReactionUpdated.prototype, "actorChat", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], MessageReactionUpdated.prototype, "date", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], MessageReactionUpdated.prototype, "oldReactions", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], MessageReactionUpdated.prototype, "newReactions", null);
MessageReactionUpdated = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], MessageReactionUpdated);
exports.MessageReactionUpdated = MessageReactionUpdated;
(0, helpers_1.memoizeGetters)(MessageReactionUpdated, ['chat', 'user', 'actorChat']);
