"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrderInfo = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const shipping_address_1 = require("./shipping-address");
const helpers_1 = require("../../utils/helpers");
/** This object represents information about an order. */
let OrderInfo = class OrderInfo {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** User name */
    get name() {
        return this.payload.name;
    }
    /** User's phone number */
    get phoneNumber() {
        return this.payload.phone_number;
    }
    /** User email */
    get email() {
        return this.payload.email;
    }
    /** User shipping address */
    get shippingAddress() {
        const { shipping_address } = this.payload;
        if (!shipping_address) {
            return;
        }
        return new shipping_address_1.ShippingAddress(shipping_address);
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], OrderInfo.prototype, "name", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], OrderInfo.prototype, "phoneNumber", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], OrderInfo.prototype, "email", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], OrderInfo.prototype, "shippingAddress", null);
OrderInfo = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], OrderInfo);
exports.OrderInfo = OrderInfo;
(0, helpers_1.memoizeGetters)(OrderInfo, ['shippingAddress']);
