"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PassportData = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const encrypted_passport_element_1 = require("./encrypted-passport-element");
const encrypted_credentials_1 = require("./encrypted-credentials");
const helpers_1 = require("../../utils/helpers");
/**
 * Contains information about Telegram Passport data shared with the bot by the
 * user.
 */
let PassportData = class PassportData {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /**
     * Array with information about documents and other Telegram Passport
     * elements that was shared with the bot
     */
    get data() {
        const { data } = this.payload;
        if (!data) {
            return;
        }
        return data.map(element => new encrypted_passport_element_1.EncryptedPassportElement(element));
    }
    /** Encrypted credentials required to decrypt the data */
    get credentials() {
        return new encrypted_credentials_1.EncryptedCredentials(this.payload.credentials);
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], PassportData.prototype, "data", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], PassportData.prototype, "credentials", null);
PassportData = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], PassportData);
exports.PassportData = PassportData;
(0, helpers_1.memoizeGetters)(PassportData, ['credentials']);
