"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PassportFile = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
/**
 * This object represents a file uploaded to Telegram Passport.
 * Currently all Telegram Passport files are in JPEG format when decrypted and
 * don't exceed 10MB.
 */
let PassportFile = class PassportFile {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /**
     * Identifier for this file, which can be used to download or reuse the file
     */
    get fileId() {
        return this.payload.file_id;
    }
    /**
     * Unique identifier for this file, which is supposed to be the same over
     * time and for different bots. Can't be used to download or reuse the file.
     */
    get fileUniqueId() {
        return this.payload.file_unique_id;
    }
    /** File size */
    get fileSize() {
        return this.payload.file_size;
    }
    /** Unix time when the file was uploaded */
    get fileDate() {
        return this.payload.file_date;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], PassportFile.prototype, "fileId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], PassportFile.prototype, "fileUniqueId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], PassportFile.prototype, "fileSize", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], PassportFile.prototype, "fileDate", null);
PassportFile = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], PassportFile);
exports.PassportFile = PassportFile;
