"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShippingQuery = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const user_1 = require("./user");
const shipping_address_1 = require("./shipping-address");
const helpers_1 = require("../../utils/helpers");
/** This object contains information about an incoming shipping query. */
let ShippingQuery = class ShippingQuery {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Unique query identifier */
    get id() {
        return this.payload.id;
    }
    /** User who sent the query */
    get from() {
        return new user_1.User(this.payload.from);
    }
    /** Sender ID */
    get senderId() {
        return this.from.id;
    }
    /** Bot specified invoice payload */
    get invoicePayload() {
        return this.payload.invoice_payload;
    }
    /** User specified shipping address */
    get shippingAddress() {
        return new shipping_address_1.ShippingAddress(this.payload.shipping_address);
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ShippingQuery.prototype, "id", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ShippingQuery.prototype, "from", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ShippingQuery.prototype, "senderId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ShippingQuery.prototype, "invoicePayload", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], ShippingQuery.prototype, "shippingAddress", null);
ShippingQuery = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], ShippingQuery);
exports.ShippingQuery = ShippingQuery;
(0, helpers_1.memoizeGetters)(ShippingQuery, ['from', 'shippingAddress']);
