"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StickerSet = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const attachments_1 = require("../attachments");
const photo_size_1 = require("./photo-size");
const helpers_1 = require("../../utils/helpers");
/** This object represents a sticker set. */
let StickerSet = class StickerSet {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Sticker set name */
    get name() {
        return this.payload.name;
    }
    /** Sticker set title */
    get title() {
        return this.payload.title;
    }
    /** Type of stickers in the set, currently one of `regular`, `mask`, `custom_emoji` */
    get stickerType() {
        return this.payload.sticker_type;
    }
    /** `true`, if the sticker set contains animated stickers */
    isAnimated() {
        return this.payload.is_animated;
    }
    /** `true`, if the sticker set contains video stickers */
    isVideo() {
        return this.payload.is_video;
    }
    /** List of all set stickers */
    get stickers() {
        const { stickers } = this.payload;
        if (!stickers.length) {
            return;
        }
        return stickers.map(sticker => new attachments_1.StickerAttachment(sticker));
    }
    /** Sticker set thumbnail in the .WEBP or .TGS format */
    get thumbnail() {
        const { thumbnail } = this.payload;
        if (!thumbnail) {
            return;
        }
        return new photo_size_1.PhotoSize(thumbnail);
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], StickerSet.prototype, "name", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], StickerSet.prototype, "title", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], StickerSet.prototype, "stickerType", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], StickerSet.prototype, "isAnimated", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true })
], StickerSet.prototype, "isVideo", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], StickerSet.prototype, "stickers", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], StickerSet.prototype, "thumbnail", null);
StickerSet = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], StickerSet);
exports.StickerSet = StickerSet;
(0, helpers_1.memoizeGetters)(StickerSet, ['thumbnail']);
