"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SuccessfulPayment = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const order_info_1 = require("./order-info");
const helpers_1 = require("../../utils/helpers");
/** This object contains basic information about a successful payment. */
let SuccessfulPayment = class SuccessfulPayment {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Three-letter ISO 4217 currency code */
    get currency() {
        return this.payload.currency;
    }
    /**
     * Total price in the smallest units of the currency
     * (integer, not float/double). For example, for a price of
     * `US$ 1.45` pass `amount = 145`. See the `exp` parameter in
     * [currencies.json](https://core.telegram.org/bots/payments/currencies.json),
     * it shows the number of digits past the decimal point for each currency
     * (2 for the majority of currencies).
     */
    get totalAmount() {
        return this.payload.total_amount;
    }
    /** Bot specified invoice payload */
    get invoicePayload() {
        return this.payload.invoice_payload;
    }
    /** Identifier of the shipping option chosen by the user */
    get shippingOptionId() {
        return this.payload.shipping_option_id;
    }
    /** Order info provided by the user */
    get orderInfo() {
        const { order_info } = this.payload;
        if (!order_info) {
            return;
        }
        return new order_info_1.OrderInfo(order_info);
    }
    /** Telegram payment identifier */
    get telegramPaymentChargeId() {
        return this.payload.telegram_payment_charge_id;
    }
    /** Provider payment identifier */
    get providerPaymentChargeId() {
        return this.payload.provider_payment_charge_id;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], SuccessfulPayment.prototype, "currency", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], SuccessfulPayment.prototype, "totalAmount", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], SuccessfulPayment.prototype, "invoicePayload", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], SuccessfulPayment.prototype, "shippingOptionId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], SuccessfulPayment.prototype, "orderInfo", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], SuccessfulPayment.prototype, "telegramPaymentChargeId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], SuccessfulPayment.prototype, "providerPaymentChargeId", null);
SuccessfulPayment = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], SuccessfulPayment);
exports.SuccessfulPayment = SuccessfulPayment;
(0, helpers_1.memoizeGetters)(SuccessfulPayment, ['orderInfo']);
