"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextQuote = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const message_entities_1 = require("../message-entities");
const message_entity_1 = require("./message-entity");
const helpers_1 = require("../../utils/helpers");
/** This object contains information about the quoted part of a message that is replied to by the given message. */
let TextQuote = class TextQuote {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Text of the quoted part of a message that is replied to by the given message */
    get text() {
        return this.payload.text;
    }
    /** Special entities that appear in the quote. Currently, only `bold`, `italic`, `underline`, `strikethrough`, `spoiler`, and `custom_emoji` entities are kept in quotes. */
    get entities() {
        const { entities } = this.payload;
        if (!entities) {
            return undefined;
        }
        return new message_entities_1.MessageEntities(...entities.map(e => new message_entity_1.MessageEntity(e)));
    }
    /** Approximate quote position in the original message in UTF-16 code units as specified by the sender */
    get position() {
        return this.payload.position;
    }
    /** `true`, if the quote was chosen manually by the message sender. Otherwise, the quote was added automatically by the server. */
    isManual() {
        return this.payload.is_manual;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], TextQuote.prototype, "text", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], TextQuote.prototype, "entities", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], TextQuote.prototype, "position", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ compute: true, nullable: false })
], TextQuote.prototype, "isManual", null);
TextQuote = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], TextQuote);
exports.TextQuote = TextQuote;
(0, helpers_1.memoizeGetters)(TextQuote, ['entities']);
