"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Venue = void 0;
const tslib_1 = require("tslib");
const inspectable_1 = require("inspectable");
const location_1 = require("./location");
const helpers_1 = require("../../utils/helpers");
/** This object represents a venue. */
let Venue = class Venue {
    constructor(payload) {
        this.payload = payload;
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    /** Venue location */
    get location() {
        return new location_1.Location(this.payload.location);
    }
    /** Name of the venue */
    get title() {
        return this.payload.title;
    }
    /** Address of the venue */
    get address() {
        return this.payload.address;
    }
    /** Foursquare identifier of the venue */
    get foursquareId() {
        return this.payload.foursquare_id;
    }
    /** Foursquare type of the venue */
    get foursquareType() {
        return this.payload.foursquare_type;
    }
    /** Google Places identifier of the venue */
    get googlePlaceId() {
        return this.payload.google_place_id;
    }
    /**
     * Google Places type of the venue.
     * (See [supported types](https://developers.google.com/places/web-service/supported_types).)
     */
    get googlePlaceType() {
        return this.payload.google_place_type;
    }
    toJSON() {
        return this.payload;
    }
};
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Venue.prototype, "location", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Venue.prototype, "title", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)()
], Venue.prototype, "address", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Venue.prototype, "foursquareId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Venue.prototype, "foursquareType", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Venue.prototype, "googlePlaceId", null);
tslib_1.__decorate([
    (0, inspectable_1.Inspect)({ nullable: false })
], Venue.prototype, "googlePlaceType", null);
Venue = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], Venue);
exports.Venue = Venue;
(0, helpers_1.memoizeGetters)(Venue, ['location']);
