import { CallbackQuery } from '../common/structures';
import { Constructor, Require } from '../types/types';
import * as Interfaces from '../generated/telegram-interfaces';
import * as Methods from '../generated/methods';
import { Telegram } from '../telegram';
import { Context } from './context';
import { MessageContext } from './message';
import { CloneMixin } from './mixins';
import { InlineKeyboard, InlineKeyboardBuilder } from '../common';
interface CallbackQueryContextOptions {
    telegram: Telegram;
    update: Interfaces.TelegramUpdate;
    payload: Interfaces.TelegramCallbackQuery;
    updateId: number;
}
/** Called when `callback_query` event occurs */
declare class CallbackQueryContext extends Context {
    payload: Interfaces.TelegramCallbackQuery;
    constructor(options: CallbackQueryContextOptions);
    /** Checks if the query has `message` property */
    hasMessage(): this is Require<this, 'message'>;
    /**
     * Message with the callback button that originated the query.
     * Note that message content and message date will not be available
     * if the message is too old
     */
    get message(): MessageContext | undefined;
    /** Checks if the query has `queryPayload` property */
    hasQueryPayload(): this is Require<this, 'queryPayload'>;
    /**
     * Data associated with the callback button.
     * Be aware that a bad client can send arbitrary data in this field.
     */
    get queryPayload(): unknown;
    /** Checks if the query has `inlineMessageId` property */
    hasInlineMessageId(): this is Require<this, 'inlineMessageId'>;
    /** Checks if the query has `data` property */
    hasData(): this is Require<this, 'data'>;
    /** Checks if the query has `gameShortName` property */
    hasGameShortName(): this is Require<this, 'gameShortName'>;
    /** Answers to current callback query */
    answerCallbackQuery(params?: Partial<Methods.AnswerCallbackQueryParams>): Promise<true>;
    /** Sets the result of an interaction with a Web App and sends a corresponding message  */
    answerWebAppQuery(params: Methods.AnswerWebAppQueryParams): Promise<Interfaces.TelegramSentWebAppMessage>;
    /** Answers to current callback query. An alias for `answerCallbackQuery` */
    answer(params?: Partial<Methods.AnswerCallbackQueryParams>): Promise<true>;
    /** Edits a callback query messages text */
    editText(text: Methods.EditMessageTextParams['text'], params?: Partial<Methods.EditMessageTextParams>): Promise<true | Interfaces.TelegramMessage> | Promise<true | MessageContext>;
    /** Edits a callback query messages caption */
    editCaption(caption: NonNullable<Methods.EditMessageCaptionParams['caption']>, params?: Partial<Methods.EditMessageCaptionParams>): Promise<true | Interfaces.TelegramMessage> | Promise<true | MessageContext>;
    /** Edits a callback query messages media */
    editMedia(media: Methods.EditMessageMediaParams['media'], params?: Partial<Methods.EditMessageMediaParams>): Promise<true | Interfaces.TelegramMessage> | Promise<true | MessageContext>;
    /** Edits a callback query messages live location */
    editLiveLocation(params: Methods.EditMessageLiveLocationParams): Promise<true | Interfaces.TelegramMessage> | Promise<true | MessageContext>;
    /** Stops a callback query messages live location */
    stopLiveLocation(params?: Methods.StopMessageLiveLocationParams): Promise<true | Interfaces.TelegramMessage> | Promise<true | MessageContext>;
    /** Edits a callback query messages reply markup */
    editReplyMarkup(replyMarkup: InlineKeyboard | InlineKeyboardBuilder | Interfaces.TelegramInlineKeyboardMarkup, params?: Partial<Methods.EditMessageReplyMarkupParams>): Promise<true | Interfaces.TelegramMessage> | Promise<true | MessageContext>;
}
interface CallbackQueryContext extends Constructor<CallbackQueryContext>, CallbackQuery, CloneMixin<CallbackQueryContext, CallbackQueryContextOptions> {
}
export { CallbackQueryContext };
