import * as Interfaces from '../generated/telegram-interfaces';
import * as Methods from '../generated/methods';
import { ChosenInlineResult } from '../common/structures';
import { Telegram } from '../telegram';
import { Constructor, Require } from '../types/types';
import { Context } from './context';
import { SendMixin, ChatActionMixin, CloneMixin } from './mixins';
import { InlineKeyboard, InlineKeyboardBuilder } from '../common';
interface ChosenInlineResultContextOptions {
    telegram: Telegram;
    update: Interfaces.TelegramUpdate;
    payload: Interfaces.TelegramChosenInlineResult;
    updateId: number;
}
/**
 * The result of an inline query that was chosen by
 * a user and sent to their chat partner
 */
declare class ChosenInlineResultContext extends Context {
    payload: Interfaces.TelegramChosenInlineResult;
    constructor(options: ChosenInlineResultContextOptions);
    /** Checks if the result has `location` property */
    hasLocation(): this is Require<this, 'location'>;
    /** Checks if the query has `inlineMessageId` property */
    hasInlineMessageId(): this is Require<this, 'inlineMessageId'>;
    /** Edits a callback query messages text */
    editText(text: Methods.EditMessageTextParams['text'], params?: Partial<Methods.EditMessageTextParams>): Promise<true | Interfaces.TelegramMessage>;
    /** Edits a callback query messages caption */
    editCaption(caption: NonNullable<Methods.EditMessageCaptionParams['caption']>, params?: Partial<Methods.EditMessageCaptionParams>): Promise<true | Interfaces.TelegramMessage>;
    /** Edits a callback query messages media */
    editMedia(media: Methods.EditMessageMediaParams['media'], params?: Partial<Methods.EditMessageMediaParams>): Promise<true | Interfaces.TelegramMessage>;
    /** Edits a callback query messages live location */
    editLiveLocation(params: Methods.EditMessageLiveLocationParams): Promise<true | Interfaces.TelegramMessage>;
    /** Stops a callback query messages live location */
    stopLiveLocation(params?: Methods.StopMessageLiveLocationParams): Promise<true | Interfaces.TelegramMessage>;
    /** Edits a callback query messages reply markup */
    editReplyMarkup(replyMarkup: InlineKeyboard | InlineKeyboardBuilder | Interfaces.TelegramInlineKeyboardMarkup, params?: Partial<Methods.EditMessageReplyMarkupParams>): Promise<true | Interfaces.TelegramMessage>;
}
interface ChosenInlineResultContext extends Constructor<ChosenInlineResultContext>, ChosenInlineResult, SendMixin, ChatActionMixin, CloneMixin<ChosenInlineResultContext, ChosenInlineResultContextOptions> {
}
export { ChosenInlineResultContext };
