"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageReactionContext = void 0;
const message_reaction_updated_1 = require("../common/structures/message-reaction-updated");
const helpers_1 = require("../utils/helpers");
const context_1 = require("./context");
const mixins_1 = require("./mixins");
const inspectable_1 = require("inspectable");
/** This object represents a change of a reaction on a message performed by a user. */
class MessageReactionContext extends context_1.Context {
    constructor(options) {
        super({
            telegram: options.telegram,
            updateType: 'message_reaction',
            updateId: options.updateId,
            update: options.update
        });
        this.payload = options.payload;
    }
    /** Checks if context has the `user` property */
    hasUser() {
        return this.user !== undefined;
    }
    /** Checks if context has the `actorChat` property */
    hasActorChat() {
        return this.actorChat !== undefined;
    }
}
exports.MessageReactionContext = MessageReactionContext;
(0, helpers_1.applyMixins)(MessageReactionContext, [message_reaction_updated_1.MessageReactionUpdated, mixins_1.SendMixin, mixins_1.NodeMixin, mixins_1.CloneMixin]);
(0, inspectable_1.inspectable)(MessageReactionContext, {
    serialize(context) {
        const payload = {
            id: context.id,
            chat: context.chat,
            user: context.user,
            actorChat: context.actorChat,
            date: context.date,
            oldReactions: context.oldReactions,
            newReactions: context.newReactions
        };
        return (0, helpers_1.filterPayload)(payload);
    }
});
