import * as Methods from '../../generated/methods';
import { Optional } from '../../types/types';
import { Context } from '../context';
import { SendMixin } from './send';
interface CreateActionControllerParams {
    /**
     * Interval between `sendChatAction` calls, in milliseconds
     * @default 5000
     */
    interval?: number;
    /**
     * Initial wait before the first cycle of `sendChatAction` calls, in milliseconds
     * @default 0
     */
    wait?: number;
    /**
     * Timeout for `sendChatAction` calls, in milliseconds. `0` to disable
     * @default 0
     */
    timeout?: number;
}
interface ControllerOptions {
    action: Methods.SendChatActionParams['action'];
    params: Optional<Methods.SendChatActionParams, 'chat_id' | 'action'> & CreateActionControllerParams;
    context: Context & SendMixin;
}
declare class ChatActionController {
    private abortController;
    action: Methods.SendChatActionParams['action'];
    interval: number;
    wait: number;
    timeout: number;
    private context;
    constructor(options: ControllerOptions);
    started: boolean;
    /** Starts the `sendChatAction(action)` loop until `stop()` is called */
    start(): void;
    /** Stops the loop */
    stop(): void;
}
declare class ChatActionMixin {
    /** Creates a controller that when `start()`ed executes `sendChatAction(action)` every `interval` milliseconds until `stop()`ped */
    createActionController(action: Methods.SendChatActionParams['action'], params?: Optional<Methods.SendChatActionParams, 'chat_id' | 'action'> & CreateActionControllerParams): ChatActionController;
}
interface ChatActionMixin extends Context, SendMixin {
}
export { ChatActionMixin };
