"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatActionMixin = void 0;
const telegram_1 = require("../../telegram");
const helpers_1 = require("../../utils/helpers");
class ChatActionController {
    constructor(options) {
        this.abortController = new AbortController();
        this.started = false;
        const { interval = 5000, wait = 0, timeout = 0 } = options.params;
        this.action = options.action;
        this.interval = interval;
        this.wait = wait;
        this.timeout = timeout;
        this.context = options.context;
    }
    /** Starts the `sendChatAction(action)` loop until `stop()` is called */
    start() {
        if (this.started) {
            return;
        }
        this.started = true;
        setImmediate(async () => {
            const start = Date.now();
            if (this.wait > 0) {
                await (0, helpers_1.sleep)(this.wait);
            }
            while (!this.abortController.signal.aborted) {
                const result = await this.context.sendChatAction(this.action, { suppress: true });
                await (0, helpers_1.sleep)(this.interval);
                // stop if we hit an error
                if (telegram_1.Telegram.isErrorResponse(result)) {
                    break;
                }
                // stop if we hit the timeout mark
                if (this.timeout !== 0 && Date.now() - start > this.timeout) {
                    break;
                }
            }
        });
    }
    /** Stops the loop */
    stop() {
        this.started = false;
        this.abortController.abort();
    }
}
class ChatActionMixin {
    /** Creates a controller that when `start()`ed executes `sendChatAction(action)` every `interval` milliseconds until `stop()`ped */
    createActionController(action, params = {}) {
        return new ChatActionController({
            action,
            params,
            context: this
        });
    }
}
exports.ChatActionMixin = ChatActionMixin;
