import * as Methods from '../../generated/methods';
import * as Interfaces from '../../generated/telegram-interfaces';
import { MediaInput } from '../../common/media-source';
import { Optional } from '../../types/types';
import { Context } from '../context';
import { NodeMixin } from './node';
import { TargetMixin } from './target';
/** This object represents a mixin that is responsible for all the chat management methods */
declare class ChatControlMixin {
    /** Sets a custom title */
    setCustomTitle(title: string, params?: Optional<Methods.SetChatAdministratorCustomTitleParams, 'chat_id' | 'user_id'>): Promise<true>;
    /** Sets default chat permissions */
    setChatDefaultPermissions(permissions: Interfaces.TelegramChatPermissions, params?: Optional<Methods.SetChatPermissionsParams, 'chat_id' | 'permissions'>): Promise<true>;
    /** Sets a new profile photo for the chat */
    setChatPhoto(photo: MediaInput, params?: Optional<Methods.SetChatPhotoParams, 'chat_id' | 'photo'>): Promise<true>;
    /** Deletes a chat photo */
    removeChatPhoto(params?: Optional<Methods.DeleteChatPhotoParams, 'chat_id'>): Promise<true>;
    /** Changes chat title */
    setChatTitle(title: string, params?: Optional<Methods.SetChatTitleParams, 'chat_id' | 'title'>): Promise<true>;
    /** Changes chat description */
    setChatDescription(description: string, params?: Optional<Methods.SetChatDescriptionParams, 'chat_id' | 'description'>): Promise<true>;
    /** Sets new group stickerset */
    setChatStickerSet(name: string, params?: Optional<Methods.SetChatStickerSetParams, 'chat_id' | 'sticker_set_name'>): Promise<true>;
    /** Deletes group stickerset */
    deleteChatStickerSet(params?: Optional<Methods.DeleteChatStickerSetParams, 'chat_id'>): Promise<true>;
}
interface ChatControlMixin extends Context, TargetMixin, NodeMixin {
}
export { ChatControlMixin };
