import * as Methods from '../../generated/methods';
import { Optional, RequireValue } from '../../types/types';
import { Context } from '../context';
import { NodeMixin } from './node';
interface ForumMixinMetadata {
    get threadId(): number | undefined;
}
/** This object represents a mixin that's used in all topic-related updates  */
declare class ForumMixin {
    /** Checks whether this topic is actually a 'General' one */
    isGeneralTopic(): this is RequireValue<this, 'threadId', undefined>;
    /** Returns custom emoji stickers, which can be used as a forum topic icon by any user */
    getTopicIcons(): Promise<import("../../generated").TelegramSticker[]>;
    /** Creates a topic */
    createTopic(name: string, params?: Optional<Methods.CreateForumTopicParams, 'chat_id' | 'name'>): Promise<import("../../generated").TelegramForumTopic>;
    /** Edits topic info */
    editTopic(params: Optional<Methods.EditForumTopicParams, 'chat_id' | 'message_thread_id'>): Promise<true>;
    /** Edits General topic info */
    editGeneralTopic(params: Optional<Methods.EditGeneralForumTopicParams, 'chat_id'>): Promise<true>;
    /** Closes topic */
    closeTopic(params?: Optional<Methods.CloseForumTopicParams, 'chat_id' | 'message_thread_id'>): Promise<true>;
    /** Closes General topic */
    closeGeneralTopic(params?: Optional<Methods.CloseGeneralForumTopicParams, 'chat_id'>): Promise<true>;
    /** Reopens topic */
    reopenTopic(params?: Optional<Methods.ReopenForumTopicParams, 'chat_id' | 'message_thread_id'>): Promise<true>;
    /** Reopens General topic */
    reopenGeneralTopic(params?: Optional<Methods.ReopenGeneralForumTopicParams, 'chat_id'>): Promise<true>;
    /** Deletes topic along with all its messages */
    deleteTopic(params?: Optional<Methods.DeleteForumTopicParams, 'chat_id' | 'message_thread_id'>): Promise<true>;
    /** Clears the list of pinned messages */
    unpinAllTopicMessages(params?: Optional<Methods.UnpinAllForumTopicMessagesParams, 'chat_id' | 'message_thread_id'>): Promise<true>;
    /** Clears the list of pinned messages in a General topic */
    unpinAllGeneralTopicMessages(params?: Optional<Methods.UnpinAllGeneralForumTopicMessagesParams, 'chat_id'>): Promise<true>;
    /** Hides General topic */
    hideGeneralTopic(params?: Optional<Methods.HideGeneralForumTopicParams, 'chat_id'>): Promise<true>;
    /** Unhides General topic */
    unhideGeneralTopic(params?: Optional<Methods.UnhideGeneralForumTopicParams, 'chat_id'>): Promise<true>;
}
interface ForumMixin extends Context, ForumMixinMetadata, NodeMixin {
}
export { ForumMixin };
