import * as Interfaces from '../../generated/telegram-interfaces';
import * as Methods from '../../generated/methods';
import { InlineKeyboard, InlineKeyboardBuilder } from '../../common/keyboards';
import { MessageId } from '../../common/structures';
import { AvailableText, Known, MaybeArray, Optional } from '../../types/types';
import { Context } from '../context';
import { SendMixin } from './send';
import { MessageContext } from '../message';
interface NodeMixinMetadata {
    get id(): number;
}
/** Construct a type that has `reply_parameters` `Partial` */
type WithPartialReplyParameters<T> = Omit<Known<T>, 'reply_parameters'> & {
    reply_parameters?: Partial<Interfaces.TelegramReplyParameters>;
} & Record<string, any>;
type WithQuote<T = {}> = {
    quote: AvailableText;
} & T;
/** This object represents a mixin which has `id` field and can invoke `id`-dependent methods */
declare class NodeMixin {
    /** Replies to current message */
    reply(text: Methods.SendMessageParams['text'], params?: WithPartialReplyParameters<Optional<Methods.SendMessageParams, 'chat_id' | 'text'>>): Promise<MessageContext>;
    /** Replies to current message with photo */
    replyWithPhoto(photo: Methods.SendPhotoParams['photo'], params?: WithPartialReplyParameters<Optional<Methods.SendPhotoParams, 'chat_id' | 'photo'>>): Promise<MessageContext>;
    /** Replies to current message with document */
    replyWithDocument(document: Methods.SendDocumentParams['document'], params?: WithPartialReplyParameters<Optional<Methods.SendDocumentParams, 'chat_id' | 'document'>>): Promise<MessageContext>;
    /** Replies to current message with audio */
    replyWithAudio(audio: Methods.SendAudioParams['audio'], params?: WithPartialReplyParameters<Optional<Methods.SendAudioParams, 'chat_id' | 'audio'>>): Promise<MessageContext>;
    /** Replies to current message with video */
    replyWithVideo(video: Methods.SendVideoParams['video'], params?: WithPartialReplyParameters<Optional<Methods.SendVideoParams, 'chat_id' | 'video'>>): Promise<MessageContext>;
    /** Replies to current message with animation */
    replyWithAnimation(animation: Methods.SendAnimationParams['animation'], params?: WithPartialReplyParameters<Optional<Methods.SendAnimationParams, 'chat_id' | 'animation'>>): Promise<MessageContext>;
    /** Replies to current message with video note */
    replyWithVideoNote(videoNote: Methods.SendVideoNoteParams['video_note'], params?: WithPartialReplyParameters<Optional<Methods.SendVideoNoteParams, 'chat_id' | 'video_note'>>): Promise<MessageContext>;
    /** Replies to current message with voice */
    replyWithVoice(voice: Methods.SendVoiceParams['voice'], params?: WithPartialReplyParameters<Optional<Methods.SendVoiceParams, 'chat_id' | 'voice'>>): Promise<MessageContext>;
    /** Replies to current message with media group */
    replyWithMediaGroup(mediaGroup: Methods.SendMediaGroupParams['media'], params?: WithPartialReplyParameters<Optional<Methods.SendMediaGroupParams, 'chat_id' | 'media'>>): Promise<MessageContext[]>;
    /** Replies to current message with location */
    replyWithLocation(latitude: number, longitude: number, params?: WithPartialReplyParameters<Optional<Methods.SendLocationParams, 'chat_id' | 'latitude' | 'longitude'>>): Promise<MessageContext>;
    /** Replies to current message with invoice */
    replyWithInvoice(params: WithPartialReplyParameters<Optional<Methods.SendInvoiceParams, 'chat_id'>>): Promise<MessageContext>;
    /** Replies to current message with venue */
    replyWithVenue(params: WithPartialReplyParameters<Optional<Methods.SendVenueParams, 'chat_id'>>): Promise<MessageContext>;
    /** Replies to current message with contact */
    replyWithContact(params: WithPartialReplyParameters<Optional<Methods.SendContactParams, 'chat_id'>>): Promise<MessageContext>;
    /** Replies to current message with poll */
    replyWithPoll(params: WithPartialReplyParameters<Optional<Methods.SendPollParams, 'chat_id'>>): Promise<MessageContext>;
    /** Replies to current message with sticker */
    replyWithSticker(sticker: Methods.SendStickerParams['sticker'], params?: WithPartialReplyParameters<Optional<Methods.SendStickerParams, 'chat_id' | 'sticker'>>): Promise<MessageContext>;
    /** Replies to current message with a dice */
    replyWithDice(emoji: Methods.SendDiceParams['emoji'], params?: WithPartialReplyParameters<Partial<Methods.SendDiceParams>>): Promise<MessageContext>;
    /** Replies to current message with a quote */
    replyWithQuote(params: WithQuote<{
        text: AvailableText;
    }> & WithPartialReplyParameters<Optional<Methods.SendMessageParams, 'chat_id' | 'text'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and a photo */
    quoteWithPhoto(params: WithQuote<{
        photo: Methods.SendPhotoParams['photo'];
    }> & WithPartialReplyParameters<Optional<Methods.SendPhotoParams, 'chat_id' | 'photo'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and a document */
    quoteWithDocument(params: WithQuote<{
        document: Methods.SendDocumentParams['document'];
    }> & WithPartialReplyParameters<Optional<Methods.SendDocumentParams, 'chat_id' | 'document'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and an audio */
    quoteWithAudio(params: WithQuote<{
        audio: Methods.SendAudioParams['audio'];
    }> & WithPartialReplyParameters<Optional<Methods.SendAudioParams, 'chat_id' | 'audio'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and a video */
    quoteWithVideo(params: WithQuote<{
        video: Methods.SendVideoParams['video'];
    }> & WithPartialReplyParameters<Optional<Methods.SendVideoParams, 'chat_id' | 'video'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and an animation */
    quoteWithAnimation(params: WithQuote<{
        animation: Methods.SendAnimationParams['animation'];
    }> & WithPartialReplyParameters<Optional<Methods.SendAnimationParams, 'chat_id' | 'animation'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and a video note */
    quoteWithVideoNote(params: WithQuote<{
        videoNote: Methods.SendVideoNoteParams['video_note'];
    }> & WithPartialReplyParameters<Optional<Methods.SendVideoNoteParams, 'chat_id' | 'video_note'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and a voice */
    quoteWithVoice(params: WithQuote<{
        voice: Methods.SendVoiceParams['voice'];
    }> & WithPartialReplyParameters<Optional<Methods.SendVoiceParams, 'chat_id' | 'voice'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and a media group */
    quoteWithMediaGroup(params: WithQuote<{
        mediaGroup: Methods.SendMediaGroupParams['media'];
    }> & WithPartialReplyParameters<Optional<Methods.SendMediaGroupParams, 'chat_id' | 'media'>>): Promise<MessageContext[]>;
    /** Replies to current message with a quote and a location */
    quoteWithLocation(params: WithQuote<{
        latitude: number;
        longitude: number;
    }> & WithPartialReplyParameters<Optional<Methods.SendLocationParams, 'chat_id' | 'latitude' | 'longitude'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and an invoice */
    quoteWithInvoice(params: WithQuote & WithPartialReplyParameters<Optional<Methods.SendInvoiceParams, 'chat_id'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and a venue */
    quoteWithVenue(params: WithQuote & WithPartialReplyParameters<Optional<Methods.SendVenueParams, 'chat_id'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and a contact */
    quoteWithContact(params: WithQuote & WithPartialReplyParameters<Optional<Methods.SendContactParams, 'chat_id'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and a poll */
    quoteWithPoll(params: WithQuote & WithPartialReplyParameters<Optional<Methods.SendPollParams, 'chat_id'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and a sticker */
    quoteWithSticker(params: WithQuote<{
        sticker: Methods.SendStickerParams['sticker'];
    }> & WithPartialReplyParameters<Optional<Methods.SendStickerParams, 'chat_id' | 'sticker'>>): Promise<MessageContext>;
    /** Replies to current message with a quote and a dice */
    quoteWithDice(params: WithQuote<{
        emoji: Methods.SendDiceParams['emoji'];
    }> & WithPartialReplyParameters<Partial<Methods.SendDiceParams>>): Promise<MessageContext>;
    /** @deprecated use `delete()` instead */
    deleteMessage(params?: Optional<Methods.DeleteMessageParams, 'chat_id' | 'message_id'>): Promise<true>;
    /** Deletes current message */
    delete(params?: Optional<Methods.DeleteMessageParams, 'chat_id' | 'message_id'>): Promise<true>;
    /** Edits current message live location */
    editMessageLiveLocation(params: Methods.EditMessageLiveLocationParams): Promise<true | MessageContext>;
    /** Edits current message live location. An alias for `editMessageLiveLocation` */
    editLiveLocation(params: Methods.EditMessageLiveLocationParams): Promise<true | MessageContext>;
    /** Stops current message live location */
    stopMessageLiveLocation(params?: Methods.StopMessageLiveLocationParams): Promise<true | MessageContext>;
    /** Stops current message live location. An alias for `stopMessageLiveLocation` */
    stopLiveLocation(params?: Methods.StopMessageLiveLocationParams): Promise<true | MessageContext>;
    /** Edits current message text */
    editMessageText(text: Methods.EditMessageTextParams['text'], params?: Partial<Methods.EditMessageTextParams>): Promise<true | MessageContext>;
    /** Edits current message text. An alias for `editMessageText` */
    editText(text: Methods.EditMessageTextParams['text'], params?: Partial<Methods.EditMessageTextParams>): Promise<true | MessageContext>;
    /** Edits current message caption */
    editMessageCaption(caption: NonNullable<Methods.EditMessageCaptionParams['caption']>, params?: Partial<Methods.EditMessageCaptionParams>): Promise<true | MessageContext>;
    /** Edits current message caption. An alias for `editMessageCaption` */
    editCaption(caption: NonNullable<Methods.EditMessageCaptionParams['caption']>, params?: Partial<Methods.EditMessageCaptionParams>): Promise<true | MessageContext>;
    /** Edits current message media */
    editMessageMedia(media: Methods.EditMessageMediaParams['media'], params?: Partial<Methods.EditMessageMediaParams>): Promise<true | MessageContext>;
    /** Edits current message media. An alias for `editMessageMedia` */
    editMedia(media: Methods.EditMessageMediaParams['media'], params?: Partial<Methods.EditMessageMediaParams>): Promise<true | MessageContext>;
    /** Edits current message reply markup */
    editMessageReplyMarkup(replyMarkup: InlineKeyboard | InlineKeyboardBuilder | Interfaces.TelegramInlineKeyboardMarkup, params?: Partial<Methods.EditMessageReplyMarkupParams>): Promise<true | MessageContext>;
    /** Edits current message reply markup. An alias for `editMessageReplyMarkup` */
    editReplyMarkup(replyMarkup: InlineKeyboard | InlineKeyboardBuilder | Interfaces.TelegramInlineKeyboardMarkup, params?: Partial<Methods.EditMessageReplyMarkupParams>): Promise<true | MessageContext>;
    /** Copies current message [into other chat if `chatId` is provided] */
    copy(params?: Optional<Methods.CopyMessageParams, 'chat_id' | 'from_chat_id' | 'message_id'>): Promise<MessageId>;
    /** Forwards current message [into other chat if `chatId` is provided] */
    forward(params?: Optional<Methods.ForwardMessageParams, 'chat_id' | 'from_chat_id' | 'message_id'>): Promise<MessageContext>;
    /** Sets a reaction on a message */
    setReaction(reaction: Interfaces.TelegramReactionTypeEmoji['emoji'] | Interfaces.TelegramReactionType, params?: Optional<Methods.SetMessageReactionParams, 'chat_id' | 'message_id'>): Promise<true>;
    /** Sets multiple amount of reactions on a message */
    setReactions(rawReactions: (Interfaces.TelegramReactionTypeEmoji['emoji'] | Interfaces.TelegramReactionType)[], params?: Optional<Methods.SetMessageReactionParams, 'chat_id' | 'message_id'>): Promise<true>;
    /** Reacts to a message */
    react(rawReactions: MaybeArray<Interfaces.TelegramReactionTypeEmoji['emoji'] | Interfaces.TelegramReactionType>, params?: Optional<Methods.SetMessageReactionParams, 'chat_id' | 'message_id'>): Promise<true>;
    /** Clears reactions from the message */
    clearReactions(params?: Optional<Methods.SetMessageReactionParams, 'chat_id' | 'message_id'>): Promise<true>;
}
interface NodeMixin extends Context, NodeMixinMetadata, SendMixin {
}
export { NodeMixin };
