import { Message } from '../common/structures';
import * as Interfaces from '../generated/telegram-interfaces';
import { Telegram } from '../telegram';
import { Constructor } from '../types/types';
import { Context } from './context';
import { CloneMixin, NodeMixin, PinsMixin, SendMixin, ChatActionMixin, TargetMixin } from './mixins';
interface UsersSharedContextOptions {
    telegram: Telegram;
    update: Interfaces.TelegramUpdate;
    payload: Interfaces.TelegramMessage;
    updateId: number;
}
/** This object contains information about the users whose identifiers were shared with the bot using a `KeyboardButtonRequestUsers` button. */
declare class UsersSharedContext extends Context {
    payload: Interfaces.TelegramMessage;
    private event;
    constructor(options: UsersSharedContextOptions);
    /** Identifier of the request */
    get requestId(): number;
    /** Identifier of the shared user. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier. The bot may not have access to the user and could be unable to use this identifier, unless the user is already known to the bot by some other means. */
    get sharedUserIds(): number[];
}
interface UsersSharedContext extends Constructor<UsersSharedContext>, Message, TargetMixin, SendMixin, ChatActionMixin, NodeMixin, PinsMixin, CloneMixin<UsersSharedContext, UsersSharedContextOptions> {
}
export { UsersSharedContext };
