"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WriteAccessAllowedContext = void 0;
const structures_1 = require("../common/structures");
const helpers_1 = require("../utils/helpers");
const context_1 = require("./context");
const inspectable_1 = require("inspectable");
const mixins_1 = require("./mixins");
class WriteAccessAllowedContext extends context_1.Context {
    constructor(options) {
        super({
            telegram: options.telegram,
            updateType: 'write_access_allowed',
            updateId: options.updateId,
            update: options.update
        });
        this.payload = options.payload;
    }
    /** Service message: user allows a bot to write messages after adding it to the attachment menu */
    get eventAllowance() {
        return new structures_1.WriteAccessAllowed(this.payload.write_access_allowed);
    }
}
exports.WriteAccessAllowedContext = WriteAccessAllowedContext;
(0, helpers_1.applyMixins)(WriteAccessAllowedContext, [structures_1.Message, mixins_1.TargetMixin, mixins_1.SendMixin, mixins_1.ChatActionMixin, mixins_1.NodeMixin, mixins_1.PinsMixin, mixins_1.CloneMixin]);
(0, helpers_1.memoizeGetters)(WriteAccessAllowedContext, ['eventAllowance']);
(0, inspectable_1.inspectable)(WriteAccessAllowedContext, {
    serialize(context) {
        return {
            fromRequest: context.eventAllowance.fromRequest,
            webAppName: context.eventAllowance.webAppName,
            fromAttachmentMenu: context.eventAllowance.fromAttachmentMenu
        };
    }
});
