"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Updates = void 0;
const tslib_1 = require("tslib");
const debug_1 = require("debug");
const inspectable_1 = require("inspectable");
const middleware_io_1 = require("middleware-io");
const media_group_1 = require("./common/media-group");
const structures_1 = require("./common/structures");
const Contexts = tslib_1.__importStar(require("./contexts"));
const errors_1 = require("./errors");
const helpers_1 = require("./utils/helpers");
const $debugger = (0, debug_1.debug)('puregram:updates');
const debug$startPolling = $debugger.extend('startPolling');
const debug$startFetchLoop = $debugger.extend('startFetchLoop');
const debug$fetchUpdates = $debugger.extend('fetchUpdates');
const debug$handleUpdate = $debugger.extend('handleUpdate');
const debug$webhook = $debugger.extend('webhook');
const debug$mediaEvents = $debugger.extend('mediaEvents');
// THIS PART OF FILE IS AUTO-GENERATED!
// SOURCE: scripts/generate-updates
// @autogenerated generate-updates-raw-events start
const rawEvents = [
    ['callback_query', Contexts.CallbackQueryContext],
    ['chat_join_request', Contexts.ChatJoinRequestContext],
    ['chat_member', Contexts.ChatMemberContext],
    ['my_chat_member', Contexts.ChatMemberContext],
    ['chosen_inline_result', Contexts.ChosenInlineResultContext],
    ['delete_chat_photo', Contexts.DeleteChatPhotoContext],
    ['group_chat_created', Contexts.GroupChatCreatedContext],
    ['inline_query', Contexts.InlineQueryContext],
    ['invoice', Contexts.InvoiceContext],
    ['left_chat_member', Contexts.LeftChatMemberContext],
    ['location', Contexts.LocationContext],
    ['message_auto_delete_timer_changed', Contexts.MessageAutoDeleteTimerChangedContext],
    ['message', Contexts.MessageContext],
    ['channel_post', Contexts.MessageContext],
    ['edited_message', Contexts.MessageContext],
    ['edited_channel_post', Contexts.MessageContext],
    ['migrate_from_chat_id', Contexts.MigrateFromChatIdContext],
    ['migrate_to_chat_id', Contexts.MigrateToChatIdContext],
    ['new_chat_members', Contexts.NewChatMembersContext],
    ['new_chat_photo', Contexts.NewChatPhotoContext],
    ['new_chat_title', Contexts.NewChatTitleContext],
    ['passport_data', Contexts.PassportDataContext],
    ['pinned_message', Contexts.PinnedMessageContext],
    ['poll_answer', Contexts.PollAnswerContext],
    ['poll', Contexts.PollContext],
    ['message_reaction', Contexts.MessageReactionContext],
    ['message_reaction_count', Contexts.MessageReactionCountContext],
    ['chat_boost', Contexts.ChatBoostContext],
    ['removed_chat_boost', Contexts.RemovedChatBoostContext],
    ['pre_checkout_query', Contexts.PreCheckoutQueryContext],
    ['proximity_alert_triggered', Contexts.ProximityAlertTriggeredContext],
    ['write_access_allowed', Contexts.WriteAccessAllowedContext],
    ['forum_topic_created', Contexts.ForumTopicCreatedContext],
    ['forum_topic_edited', Contexts.ForumTopicEditedContext],
    ['forum_topic_closed', Contexts.ForumTopicClosedContext],
    ['forum_topic_reopened', Contexts.ForumTopicReopenedContext],
    ['general_forum_topic_hidden', Contexts.GeneralForumTopicHiddenContext],
    ['general_forum_topic_unhidden', Contexts.GeneralForumTopicUnhiddenContext],
    ['shipping_query', Contexts.ShippingQueryContext],
    ['successful_payment', Contexts.SuccessfulPaymentContext],
    ['users_shared', Contexts.UsersSharedContext],
    ['chat_shared', Contexts.ChatSharedContext],
    ['video_chat_ended', Contexts.VideoChatEndedContext],
    ['video_chat_participants_invited', Contexts.VideoChatParticipantsInvitedContext],
    ['video_chat_scheduled', Contexts.VideoChatScheduledContext],
    ['video_chat_started', Contexts.VideoChatStartedContext],
    ['web_app_data', Contexts.WebAppDataContext],
    ['giveaway_created', Contexts.GiveawayCreatedContext],
    ['giveaway_completed', Contexts.GiveawayCompletedContext],
    ['giveaway_winners', Contexts.GiveawayWinnersContext],
    ['service_message', Contexts.MessageContext]
];
// @autogenerated generate-updates-raw-events end
const makeContexts = () => {
    const contexts = {};
    for (const [event, UpdateContext] of rawEvents) {
        contexts[event] = UpdateContext;
    }
    return contexts;
};
const events = makeContexts();
/**
 * Updates class. Anything related to receiving or processing updates belongs to here
 *
 * @example
 * ```js
 * telegram.updates.on('message', context => context.reply('stfu im listening to\n\nlistening to C418 - Sweden'))
 * telegram.updates.startPolling()
 * ```
 */
let Updates = class Updates {
    constructor(telegram) {
        this.retries = 0;
        this.isStarted = false;
        this.offset = 0;
        this.composer = structures_1.Composer.builder()
            .caught((_context, error) => console.error(error));
        this.telegram = telegram;
        this.recompose();
    }
    get [Symbol.toStringTag]() {
        return this.constructor.name;
    }
    use(rawMiddlewares) {
        const middlewares = Array.isArray(rawMiddlewares) ? rawMiddlewares : [rawMiddlewares];
        for (const middleware of middlewares) {
            if (typeof middleware !== 'function') {
                throw new TypeError('middleware must be a function');
            }
            this.composer.use(middleware);
        }
        this.recompose();
        return this;
    }
    on(rawOnEvents, rawHandlers) {
        const onEvents = Array.isArray(rawOnEvents)
            ? rawOnEvents
            : [rawOnEvents];
        const hasEvents = onEvents.every(Boolean);
        if (!hasEvents) {
            throw new TypeError('events must be not empty');
        }
        const handler = Array.isArray(rawHandlers)
            ? (0, middleware_io_1.compose)(rawHandlers)
            : rawHandlers;
        if (typeof handler !== 'function') {
            throw new TypeError('handler must be a function');
        }
        return this.use((context, next) => (context.is(onEvents)
            ? handler(context, next)
            : next()));
    }
    /** Calls up the middleware chain */
    dispatchMiddleware(context) {
        return this.composed(context, middleware_io_1.noopNext);
    }
    recompose() {
        this.composed = this.composer.compose();
    }
    /**
     * Stops polling bot updates. What did you expect me to write here?
     *
     * @example
     * ```js
     * telegram.updates.startPolling()
     *   .then(() => telegram.updates.stopPolling())
     *   .then(() => console.log(':trollface:'))
     * ```
     */
    stopPolling() {
        this.isStarted = false;
        this.retries = 0;
    }
    /**
     * Starts polling bot updates
     *
     * @example
     * ```js
     * telegram.updates.startPolling()
     *   .then(() => console.log('started polling updates!'))
     *   .catch(error => console.error('an error has occurred! %o', error))
     * ```
     */
    async startPolling(options = {}) {
        if (this.isStarted) {
            throw new Error('polling is already started!');
        }
        if (!this.telegram.options.token) {
            throw new TypeError('token is not set. perhaps you forgot to set it?');
        }
        if (!this.telegram.bot) {
            debug$startPolling('fetching bot data...');
            let me;
            try {
                me = await this.telegram.api.getMe();
            }
            catch (error) {
                debug$startPolling('unable to fetch bot info, perhaps no internet connection?');
                throw new errors_1.TelegramError({
                    error_code: -1,
                    description: 'unable to fetch bot data from the start',
                    cause: error
                });
            }
            const bot = new structures_1.User(me);
            this.telegram.bot = bot;
            debug$startPolling('bot data fetched successfully: %O', bot);
        }
        this.isStarted = true;
        try {
            this.startFetchLoop(options);
        }
        catch (error) {
            this.isStarted = false;
            throw error;
        }
        return true;
    }
    /**
     * Drops pending bot updates. Returns amount of dropped updates
     * @param value If you want to skip specific updates, pass an array of update types you want to skip
     *
     * @example
     * ```js
     * const droppedUpdates = await telegram.updates.dropPendingUpdates()
     * console.log('yay! dropped %d updates!', droppedUpdates)
     *
     * await telegram.updates.startPolling()
     * ```
     */
    async dropPendingUpdates(value) {
        // TODO:
        //   await this.telegram.api.deleteWebhook()
        let offset = 0;
        let skippedUpdates = 0;
        while (true) {
            const allowedUpdates = Array.isArray(value) ? value : [];
            const updates = await this.telegram.api.getUpdates({
                offset,
                allowed_updates: allowedUpdates
            });
            if (updates.length === 0) {
                break;
            }
            skippedUpdates += updates.length;
            offset = updates[updates.length - 1].update_id + 1;
        }
        if (skippedUpdates !== 0) {
            debug$startFetchLoop('skipped %d updates', skippedUpdates);
        }
        return skippedUpdates;
    }
    // FIXME: unacceptable return type
    getWebhookMiddleware(secret) {
        return async (req, res) => {
            // INFO: Telegram sends only POST requests
            if (req.method !== 'POST') {
                return;
            }
            const reqBody = req.body;
            let update;
            try {
                update = typeof reqBody === 'object' ? reqBody : await (0, helpers_1.parseRequestJSON)(req);
            }
            catch (error) {
                return debug$webhook('an error has occurred: %O', error);
            }
            // INFO: failed to parse the update body
            if (update === undefined) {
                res.writeHead(500);
                res.end();
                throw new Error('req.body is undefined. are you sure you parsed it (e.g. via body-parser)?');
            }
            res.writeHead(200);
            res.end();
            const secretToken = req.headers['x-telegram-bot-api-secret-token'];
            // INFO: secrets do not match
            if (secret !== undefined && secretToken !== secret) {
                return debug$webhook(`received X-Telegram-Bot-API-Secret-Token="${secretToken}", but it does not match with our secret="${secret}", ignoring`);
            }
            setImmediate(() => this.handleUpdate(update));
        };
    }
    async startFetchLoop(options) {
        try {
            if (options.dropPendingUpdates) {
                await this.dropPendingUpdates(options.dropPendingUpdates);
            }
            while (this.isStarted) {
                await this.fetchUpdates(options);
            }
        }
        catch (error) {
            debug$startFetchLoop('an error has occurred: %O', error);
            if (error instanceof errors_1.APIError && error.code === 409) {
                if (this.telegram.options.apiRetryLimit !== -1) {
                    return debug$startFetchLoop('unable to start the fetch loop: other bot is probably using `getUpdates` already');
                }
            }
            if (this.telegram.options.apiRetryLimit === -1) {
                debug$startFetchLoop('trying to reconnect...');
            }
            else if (this.retries === this.telegram.options.apiRetryLimit) {
                if (this.telegram.options.apiRetryLimit === 0) {
                    return debug$startFetchLoop('`apiRetryLimit` is set to %d, not trying to reconnect', 0);
                }
                return debug$startFetchLoop('tried to reconnect %d times but it didn\'t work, cya next time', this.retries);
            }
            else {
                this.retries += 1;
                debug$startFetchLoop('trying to reconnect, %d/%d try', this.retries, this.telegram.options.apiRetryLimit);
            }
            await (0, helpers_1.delay)(this.telegram.options.apiWait);
            // INFO: not this.stopPolling() because it resets this.retries
            this.isStarted = false;
            this.startPolling();
        }
    }
    /**
     * Handles specified update and returns an appropriate `Context` (if it does exist)
     *
     * If you don't want puregram to automatically process (dispatch) that context, pass `false` for the second argument
     *
     * @example
     * ```js
     * const [update] = await telegram.api.getUpdates(params)
     * const context = telegram.updates.handleUpdate(update, false)
     *
     * if (context === undefined) {
     *   console.log(':sadface: context not found for this update!')
     *
     *   return cry()
     * }
     *
     * console.log('hell yeah im pro')
     * ```
     */
    handleUpdate(update, dispatch = true) {
        var _a, _b, _c;
        if (dispatch) {
            this.offset = update.update_id + 1;
        }
        // TODO: is it actually safe? probably
        const type = Object.keys(update)[1];
        let UpdateContext = events[type];
        if (!UpdateContext) {
            debug$handleUpdate('unsupported context type `%s`', type);
            UpdateContext = Contexts.UnsupportedContext;
        }
        debug$handleUpdate('update payload: %j', update[type]);
        let context = new UpdateContext({
            update,
            type,
            updateId: update.update_id,
            telegram: this.telegram,
            payload: update[type]
        });
        if (context.isEvent && context.eventType !== undefined) {
            debug$handleUpdate('is event: %s, updating context', context.eventType);
            UpdateContext = events[context.eventType];
            // debug$handleUpdate('UpdateContext: %O, update.message: %O', UpdateContext, update.message)
            // debug$handleUpdate('update: %O, context: %O', update, context)
            context = new UpdateContext({
                update,
                updateId: update.update_id,
                type: context.eventType,
                telegram: this.telegram,
                // TODO: detect actual key
                payload: (_c = (_b = (_a = update.message) !== null && _a !== void 0 ? _a : update.edited_message) !== null && _b !== void 0 ? _b : update.channel_post) !== null && _c !== void 0 ? _c : update.edited_channel_post
            });
        }
        debug$handleUpdate('constructed context: %O', context);
        // INFO: this sends the built context to the middleware chain
        if (dispatch) {
            this.dispatchMiddleware(context);
        }
        return context;
    }
    // FIXME: unacceptable return type
    getKoaMiddleware(secret) {
        return async (context) => {
            const update = context.request.body;
            // INFO: failed to parse the update body
            if (update === undefined) {
                context.status = 500;
                throw new Error('request.body is undefined. are you sure you parsed it (e.g. via koa-body)?');
            }
            const secretToken = context.headers['x-telegram-bot-api-secret-token'];
            // INFO: secrets do not match
            if (secret !== undefined && secretToken !== secret) {
                debug$webhook(`received X-Telegram-Bot-API-Secret-Token="${secretToken}", but it does not match with our secret="${secret}", ignoring`);
                context.status = 200;
                return;
            }
            context.status = 200;
            context.set('connection', 'keep-alive');
            setImmediate(() => this.handleUpdate(update));
        };
    }
    async fetchUpdates(options) {
        var _a;
        const params = {
            timeout: 15,
            allowed_updates: (_a = options.allowedUpdates) !== null && _a !== void 0 ? _a : this.telegram.options.allowedUpdates
        };
        if (this.offset) {
            params.offset = this.offset;
        }
        if (options.offset) {
            params.offset = options.offset;
        }
        if (options.timeout) {
            params.timeout = options.timeout;
        }
        let updates = await this.telegram.api.getUpdates(params);
        if (!updates) {
            // INFO: something is wrong with the internet connection I can feel it...
            debug$fetchUpdates('unable to get updates');
            this.stopPolling();
            this.startPolling();
            return;
        }
        if (!updates.length) {
            return;
        }
        // INFO: optimize?
        if (this.telegram.options.mergeMediaEvents) {
            const possibleUpdateTypes = ['message', 'edited_message', 'channel_post', 'edited_channel_post'];
            const getMessage = (update) => {
                const key = possibleUpdateTypes.find(ut => update[ut]);
                return update[key];
            };
            const mediaEventUpdates = updates
                .filter(update => possibleUpdateTypes.some(ut => update[ut] !== undefined))
                .filter(update => getMessage(update).media_group_id !== undefined);
            if (mediaEventUpdates.length !== 0) {
                const mediaGroupIdsMap = new Map();
                const mediaGroupIds = [...new Set(mediaEventUpdates.map(me => getMessage(me).media_group_id))];
                for (const meId of mediaGroupIds) {
                    const updates = mediaEventUpdates.filter(me => getMessage(me).media_group_id === meId);
                    mediaGroupIdsMap.set(meId, updates);
                }
                debug$mediaEvents('MG map: %O', mediaGroupIdsMap);
                for (const [mgId, mgUpdates] of mediaGroupIdsMap.entries()) {
                    const contexts = await Promise.all(mgUpdates.map(mgu => this.handleUpdate(mgu, false)));
                    const mediaGroup = new media_group_1.MediaGroup({
                        id: mgId,
                        contexts,
                        telegram: this.telegram
                    });
                    // INFO: creating [MediaGroup] on top of the first context
                    const context = contexts[0].clone();
                    context.mediaGroup = mediaGroup;
                    await this.dispatchMiddleware(context);
                    this.offset = mgUpdates.at(-1).update_id + 1;
                }
                // INFO: clearing out original [updates]
                updates = updates.filter(update => !mediaGroupIdsMap.has(getMessage(update).media_group_id));
            }
        }
        debug$fetchUpdates('updates: %O', updates);
        for (const update of updates) {
            try {
                this.handleUpdate(update);
            }
            catch (error) {
                debug$fetchUpdates('an error has occurred: %O', error);
            }
        }
    }
};
Updates = tslib_1.__decorate([
    (0, inspectable_1.Inspectable)()
], Updates);
exports.Updates = Updates;
